/*= R&S SMB Signal Generator Include File ===================================*/
/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/

#ifndef __RSSMB_HEADER
#define __RSSMB_HEADER

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif
#include <visa.h>
/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_WARN_NSUP_ID_QUERY     (          0x3FFC0101L)
#define VI_WARN_NSUP_RESET        (          0x3FFC0102L)
#define VI_WARN_NSUP_SELF_TEST    (          0x3FFC0103L)
#define VI_WARN_NSUP_ERROR_QUERY  (          0x3FFC0104L)
#define VI_WARN_NSUP_REV_QUERY    (          0x3FFC0105L)

#define VI_ERROR_FAIL_ID_QUERY    (_VI_ERROR+0x3FFC0011L)
#define VI_ERROR_INV_RESPONSE     (_VI_ERROR+0x3FFC0012L)
#define VI_ERROR_INSTR_PARAMETER  (_VI_ERROR+0x3FFC0810L)

#define VI_ERROR_INSTR_FILE_OPEN                    (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE                   (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE        (_VI_ERROR+0x3FFC0803L)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                          (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                       (_VI_ERROR+0x3FFC0900L)

#define RSSMB_ERROR_INSTRUMENT_ERROR                (VI_ERROR_INSTR_OFFSET + 0xF0L)
/* Add instrument driver specific error codes here */

#define RSSMB_ERROR_INVALID_CONFIGURATION           (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSSMB_ERROR_INSTRUMENT_OPTION               (VI_ERROR_INSTR_OFFSET + 0xF2L)
#define RSSMB_ERROR_INSTRUMENT_NSUP_MODEL           (VI_ERROR_INSTR_OFFSET + 0xF3L)
#define RSSMB_ERROR_SETTINGS_CONFLICT               (VI_ERROR_INSTR_OFFSET + 0xF4L)
#define RSSMB_ERROR_CALIBRATION_FAILED              (VI_ERROR_INSTR_OFFSET + 0xF5L)
#define RSSMB_ERROR_INSTRUMENT_DATA_NOT_AVAILABLE   (VI_ERROR_INSTR_OFFSET + 0xF6L)
/* Add instrument driver specific warning codes here */
#define RSSMB_WARNING_SMALL_BUFFER                  (VI_WARNING_INSTR_OFFSET + 0xF1L)


/*****************************************************************************/
/*= Instrument specific defines =============================================*/
/*****************************************************************************/

/* --- Set RF Frequency on Recall ------------------------------------------ */

#define RSSMB_FREQUENCY_RCL_INCLUDE                         0
#define RSSMB_FREQUENCY_RCL_EXCLUDE                         1

/* --- Set RF Level on Recall ---------------------------------------------- */

#define RSSMB_POWER_LEVEL_RCL_INCLUDE                       0
#define RSSMB_POWER_LEVEL_RCL_EXCLUDE                       1

/* --- Set ROSC Source ----------------------------------------------------- */

#define RSSMB_ROSC_SOURCE_INTERNAL                          0
#define RSSMB_ROSC_SOURCE_EXTERNAL                          1

/* --- Set ROSC External Reference Frequency ------------------------------- */

#define RSSMB_EXTERN_REF_FREQ_10MHZ                         0

/* --- Set ROSC Synchronization Bandwidth ---------------------------------- */

#define RSSMB_ROSC_SBAN_STANDARD                            0
#define RSSMB_ROSC_SBAN_NARROW                              1

/* --- Set Attenuator Mode ------------------------------------------------- */

#define RSSMB_OUTPUT_AMODE_AUTO                             0
#define RSSMB_OUTPUT_AMODE_FIXED                            1

/* --- Set Power On State -------------------------------------------------- */

#define RSSMB_OUTPUT_STATE_PON_OFF                          0
#define RSSMB_OUTPUT_STATE_PON_UNCHANGED                    1

/* --- ALC State ----------------------------------------------------------- */

#define RSSMB_POWER_ALC_STATE_OFF                           0
#define RSSMB_POWER_ALC_STATE_ON                            1   
#define RSSMB_POWER_ALC_STATE_AUTO                          2

/* --- Set LF Sweep Spacing ----------------------------------------------- */
#define RSSMB_LFOUTPUT_SWEEP_FREQUENCY_SPACING_LINEAR       0
#define RSSMB_LFOUTPUT_SWEEP_FREQUENCY_SPACING_LOGARITHMIC  1

/* --- Set CSYN Power Output Mode ----------------------------------------- */

#define RSSMB_CSYN_POWER_MODE_ECL                           0
#define RSSMB_CSYN_POWER_MODE_CMOS                          1

/* --- Set AM Source ------------------------------------------------------ */

#define RSSMB_AM_SOURCE_INT                                 0
#define RSSMB_AM_SOURCE_EXT                                 1

/* --- Set AM External Coupling ------------------------------------------- */

#define RSSMB_AM_EXTERNAL_COUPLING_AC                       0
#define RSSMB_AM_EXTERNAL_COUPLING_DC                       1

/* --- Set PULM Polarity -------------------------------------------------- */

#define RSSMB_PULM_POLARITY_NORMAL                          0
#define RSSMB_PULM_POLARITY_INVERTED                        1

/* --- Set PULM Source ---------------------------------------------------- */

#define RSSMB_PULM_SOURCE_INTERNAL                          0
#define RSSMB_PULM_SOURCE_EXTERNAL                          1

/* --- Set PULM Trigger Mode ---------------------------------------------- */

#define RSSMB_PULM_TRIGGER_MODE_AUTO                        0
#define RSSMB_PULM_TRIGGER_MODE_EXTERNAL                    1
#define RSSMB_PULM_TRIGGER_MODE_EGATE                       2

/* --- Set Mod Source ----------------------------------------------------- */

#define RSSMB_MODULATION_SOURCE_INT                         0
#define RSSMB_MODULATION_SOURCE_EXT                         1
#define RSSMB_MODULATION_SOURCE_INTEXT                      2

/* --- Set FM Mode -------------------------------------------------------- */

#define RSSMB_FM_MODE_NORMAL                                0
#define RSSMB_FM_MODE_LNOIS                                 1
#define RSSMB_FM_MODE_HDEV                                  2

/* --- Set PM Mode -------------------------------------------------------- */

#define RSSMB_PM_MODE_NORM                                  0
#define RSSMB_PM_MODE_HDEV                                  2
#define RSSMB_PM_MODE_LNOIS                                 1

/* --- Set FM External Coupling ------------------------------------------- */

#define RSSMB_EXTERNAL_COUPLING_AC                          0
#define RSSMB_EXTERNAL_COUPLING_DC                          1

/* --- Set FM External Digital Mode --------------------------------------- */

#define RSSMB_FM_EXTERNAL_DIGITAL_MODE_AUTO                 0
#define RSSMB_FM_EXTERNAL_DIGITAL_MODE_LNOIS                1
#define RSSMB_FM_EXTERNAL_DIGITAL_MODE_WIDE                 2

/* --- Set NOISE Distribution --------------------------------------------- */

#define RSSMB_NOISE_DISTRIBUTION_GAUSS                      0
#define RSSMB_NOISE_DISTRIBUTION_EQUAL                      1

/* --- Set Instrument Trigger Input Slope --------------------------------- */

#define RSSMB_INPUT_TRIGGER_SLOPE_NEGATIVE                  0
#define RSSMB_INPUT_TRIGGER_SLOPE_POSITIVE                  1

/* --- Frequency Sweep Mode ------------------------------------------------ */

#define RSSMB_SWEEP_MODE_AUTO                               0
#define RSSMB_SWEEP_MODE_SINGLE                             1
#define RSSMB_SWEEP_MODE_STEP                               2
#define RSSMB_SWEEP_MODE_EXT_SINGLE                         3
#define RSSMB_SWEEP_MODE_EXT_STEP                           4
#define RSSMB_SWEEP_MODE_EXT_HOP                            5
#define RSSMB_SWEEP_MODE_EXT_DHOP                           6

#define RSSMB_LIST_SWEEP_MODE_AUTO                          0
#define RSSMB_LIST_SWEEP_MODE_STEP                          1

    
#define RSSMB_SWEEP_LOW_MODE_AUTO                           0
#define RSSMB_SWEEP_LOW_MODE_MAN                            1
#define RSSMB_SWEEP_LOW_MODE_STEP                           2

#define RSSMB_FREQ_CENTER_SPAN                              0
#define RSSMB_FREQ_START_STOP                               1

#define RSSMB_FREQ_SWEEP_MODE_AUTO                          0
#define RSSMB_FREQ_SWEEP_MODE_SINGLE                        1
#define RSSMB_FREQ_SWEEP_MODE_STEP                          2
#define RSSMB_FREQ_SWEEP_MODE_EXT_SINGLE                    3
#define RSSMB_FREQ_SWEEP_MODE_EXT_STEP                      4

/* --- TRIGger SOURce All Sweeps ------------------------------------------- */

#define RSSMB_TRIG_SOURCE_SWEEP_AUTO                        0
#define RSSMB_TRIG_SOURCE_SWEEP_SINGLE                      1
#define RSSMB_TRIG_SOURCE_SWEEP_EXTERNAL                    2
#define RSSMB_TRIG_SOURCE_SWEEP_EAUT                        3

/* --- FREQuency Mode ------------------------------------------------------ */

#define RSSMB_FREQUENCY_MODE_CW                             0
#define RSSMB_FREQUENCY_MODE_SWEEP                          1
#define RSSMB_FREQUENCY_MODE_LIST                           2

/* --- Frequency Sweep Spacing --------------------------------------------- */

#define RSSMB_FREQ_SWEEP_SPACING_LIN                        0
#define RSSMB_FREQ_SWEEP_SPACING_LOG                        1

/* --- POWer RF Level Mode ------------------------------------------------- */

#define RSSMB_POWER_MODE_CW                                 0
#define RSSMB_POWER_MODE_SWEEP                              1
#define RSSMB_POWER_MODE_LIST                               2

/* --- LFOutput Mode ------------------------------------------------------- */

#define RSSMB_LFOUTPUT_FREQUENCY_MODE_CW                    0
#define RSSMB_LFOUTPUT_FREQUENCY_MODE_SWEEP                 1

/* --- TRIGger SOURce RF Level Sweep --------------------------------------- */

#define RSSMB_TRIG_SOURCE_RF_LEVEL_SWEEP_AUTO               0
#define RSSMB_TRIG_SOURCE_RF_LEVEL_SWEEP_IMMEDIATE          1
#define RSSMB_TRIG_SOURCE_RF_LEVEL_SWEEP_SINGLE             2
#define RSSMB_TRIG_SOURCE_RF_LEVEL_SWEEP_EXTERNAL           3
#define RSSMB_TRIG_SOURCE_RF_LEVEL_SWEEP_BUS                4

/* --- LIST Trigger Source ------------------------------------------------- */

#define RSSMB_LIST_TRIGGER_SOURCE_AUTO                      0
#define RSSMB_LIST_TRIGGER_SOURCE_SINGLE                    1
#define RSSMB_LIST_TRIGGER_SOURCE_EXTERNAL                  2
#define RSSMB_LIST_TRIGGER_SOURCE_HOP                       3
#define RSSMB_LIST_TRIGGER_SOURCE_DHOP                      4
/* --- Frequency Sweep Mode ------------------------------------------------ */

#define RSSMB_LEVEL_SWEEP_MODE_AUTO                         0
#define RSSMB_LEVEL_SWEEP_MODE_MANUAL                       1
#define RSSMB_LEVEL_SWEEP_MODE_STEP                         2

/* --- Registers ----------------------------------------------------------- */
#define RSSMB_REGISTER_OPERATION                            0
#define RSSMB_REGISTER_QUESTIONABLE                         1

#define RSSMB_REGISTER_COND                                 0
#define RSSMB_REGISTER_EVENT                                1
#define RSSMB_REGISTER_ENABLE                               2
#define RSSMB_REGISTER_NTR                                  3
#define RSSMB_REGISTER_PTR                                  4
/* --- Set LFGen Shape ----------------------------------------------------- */
#define RSSMB_LFOUTPUT_SHAPE_SINE                           0
#define RSSMB_LFOUTPUT_SHAPE_SQUARE                         1
    
/* --- TEST ---------------------------------------------------------------- */

#define RSSMB_TEST_COMMAND_SSYN                             0
#define RSSMB_TEST_COMMAND_SSYNEX                           1
#define RSSMB_TEST_COMMAND_IQOP3                            2
#define RSSMB_TEST_COMMAND_IQOP6                            3
#define RSSMB_TEST_COMMAND_SATT3                            4
#define RSSMB_TEST_COMMAND_SATT6                            5
#define RSSMB_TEST_COMMAND_BBINS                            6
#define RSSMB_TEST_COMMAND_DIRECTLAST                       7
    
/* --- VOR Mode ------------------------------------------------------------ */

#define RSSMB_VORM_MODE_NORM                                0
#define RSSMB_VORM_MODE_VAR                                 1
#define RSSMB_VORM_MODE_SUBC                                2
#define RSSMB_VORM_MODE_FMS                                 3
    
/* --- VOR Direction ------------------------------------------------------- */

#define RSSMB_VORM_DIR_FROM                                 0
#define RSSMB_VORM_DIR_TO                                   1
    
/* --- EXT AM -------------------------------------------------------------- */

#define RSSMB_VORM_SRC_INT                                  0
#define RSSMB_VORM_SRC_EXT                                  1
    
/* --- ILS GS Mode --------------------------------------------------------- */

#define RSSMB_ILSGSM_MODE_NORM                              0
#define RSSMB_ILSGSM_MODE_ULOB                              1
#define RSSMB_ILSGSM_MODE_LLOB                              2
    
/* --- ILS GS Fly Direction ------------------------------------------------ */

#define RSSMB_ILSGSM_DDM_DIR_UP                             0
#define RSSMB_ILSGSM_DDM_DIR_DOWN                           1
    
/* --- EXT AM -------------------------------------------------------------- */

#define RSSMB_ILSGSM_SRC_INT                                0
#define RSSMB_ILSGSM_SRC_EXT                                1
    
/* --- ILS LOC Mode -------------------------------------------------------- */

#define RSSMB_ILSLOCM_MODE_NORM                             0
#define RSSMB_ILSLOCM_MODE_LLOB                             1
#define RSSMB_ILSLOCM_MODE_RLOB                             2
    
/* --- ILS LOC Fly Direction ----------------------------------------------- */

#define RSSMB_ILSLOCM_DDM_DIR_LEFT                          0
#define RSSMB_ILSLOCM_DDM_DIR_RIGHT                         1
    
/* --- Marker Beacon Marker Frequency -------------------------------------- */

#define RSSMB_MBM_MARKER_FREQ_400                           0
#define RSSMB_MBM_MARKER_FREQ_1300                          1
#define RSSMB_MBM_MARKER_FREQ_3000                          2
    
/* --- LIST Import Export List Mode ---------------------------------------- */

#define RSSMB_DEXC_MODE_IMPORT                              0
#define RSSMB_DEXC_MODE_EXPORT                              1
    
/* --- LIST Import Export ASCII Extension ---------------------------------- */

#define RSSMB_DEXC_ASCII_SOURCE_FILE_EXT_TXT                0
#define RSSMB_DEXC_ASCII_SOURCE_FILE_EXT_CSV                1
    
/* --- LIST Import Export ASCII Column Separator --------------------------- */

#define RSSMB_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_TAB         0
#define RSSMB_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_SEM         1
#define RSSMB_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_COMMA       2
#define RSSMB_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_SPACE       3
    
/* --- LIST Import Export ASCII Column Decimal Separator ------------------- */

#define RSSMB_DEXC_ASCII_SOURCE_FILE_COLUMN_DEC_SEP_DOT     0
#define RSSMB_DEXC_ASCII_SOURCE_FILE_COLUMN_DEC_SEP_COMMA   1
    
/* --- Power Unit ---------------------------------------------------------- */

#define RSSMB_SENSE_POWER_UNIT_DBM                          0
#define RSSMB_SENSE_POWER_UNIT_DBUV                         1
#define RSSMB_SENSE_POWER_UNIT_WATT                         2
    
/* --- Power Source -------------------------------------------------------- */

#define RSSMB_SENSE_POWER_SOURCE_RF                         0
#define RSSMB_SENSE_POWER_SOURCE_USER                       1
    
/* --- Power Filter Type --------------------------------------------------- */

#define RSSMB_SENSE_POWER_FILTER_TYPE_AUTO                  0
#define RSSMB_SENSE_POWER_FILTER_TYPE_USER                  1
#define RSSMB_SENSE_POWER_FILTER_TYPE_NSR                   2
    
/* --- Keyboard Layout ----------------------------------------------------- */

#define RSSMB_SYSTEM_KEYBOARD_US                            0
#define RSSMB_SYSTEM_KEYBOARD_DE                            1
    
/* --- Network IP Address Mode --------------------------------------------- */

#define RSSMB_SYSTEM_COMMUNICATE_IP_MODE_STATIC             0
#define RSSMB_SYSTEM_COMMUNICATE_IP_MODE_P2P                1
#define RSSMB_SYSTEM_COMMUNICATE_IP_MODE_AUTO               2
    
/* --- Network DNS Mode ---------------------------------------------------- */

#define RSSMB_SYSTEM_COMMUNICATE_DNS_MODE_STATIC            0
#define RSSMB_SYSTEM_COMMUNICATE_DNS_MODE_AUTO              1

/* --- LF Sweep Source ----------------------------------------------------- */

#define RSSMB_LFSWEEP_SOURCE_LF1                            0
#define RSSMB_LFSWEEP_SOURCE_LF2                            1
    
#define RSSMB_INPUT_IMPEDANCE_G50                           0
#define RSSMB_INPUT_IMPEDANCE_G10K                          1
#define RSSMB_INPUT_IMPEDANCE_G600                          2
#define RSSMB_INPUT_IMPEDANCE_HIGH                          3
#define RSSMB_INPUT_IMPEDANCE_LOW                           4

/* --- Units --------------------------------------------------------------- */
#define RSSMB_UNIT_ANGLE_DEG                                0
#define RSSMB_UNIT_ANGLE_RAD                                1
   /* --- Velocity --- */
#define RSSMB_UNIT_VELOCITY_MPS                             0
#define RSSMB_UNIT_VELOCITY_KMH                             1
#define RSSMB_UNIT_VELOCITY_MPH                             2
    
/* --- HCOPY --------------------------------------------------------------- */
    
#define RSSMB_HCOPY_LANG_BMP                                0
#define RSSMB_HCOPY_LANG_JPG                                1
#define RSSMB_HCOPY_LANG_XPM                                2
#define RSSMB_HCOPY_LANG_PNG                                3
    
/* --- Sweep Shape --------------------------------------------------------- */
#define RSSMB_FREQ_SWEEP_SHAPE_SAWT                         0
#define RSSMB_FREQ_SWEEP_SHAPE_TRI                          1

/* --- ARI BK Code --------------------------------------------------------- */
#define RSSMB_STEREO_ARI_BK_CODE_A                          0
#define RSSMB_STEREO_ARI_BK_CODE_B                          1
#define RSSMB_STEREO_ARI_BK_CODE_C                          2
#define RSSMB_STEREO_ARI_BK_CODE_D                          3
#define RSSMB_STEREO_ARI_BK_CODE_E                          4
#define RSSMB_STEREO_ARI_BK_CODE_F                          5
    
/* --- ARI Type ------------------------------------------------------------ */
#define RSSMB_STEREO_ARI_TYPE_OFF                           0
#define RSSMB_STEREO_ARI_TYPE_DK                            1
#define RSSMB_STEREO_ARI_TYPE_BK                            2
#define RSSMB_STEREO_ARI_TYPE_BKDK                          3
    
/* --- Audio Mode ---------------------------------------------------------- */
#define RSSMB_STEREO_AUDIO_MODE_LEFT                        0
#define RSSMB_STEREO_AUDIO_MODE_RIGH                        1
#define RSSMB_STEREO_AUDIO_MODE_REL                         2
#define RSSMB_STEREO_AUDIO_MODE_REML                        3
#define RSSMB_STEREO_AUDIO_MODE_RNEL                        4
    
/* --- Audio Preemphasis---------------------------------------------------- */
#define RSSMB_STEREO_AUDIO_PREE_50                          0
#define RSSMB_STEREO_AUDIO_PREE_75                          1
    
/* --- RDS Data Set -------------------------------------------------------- */
#define RSSMB_STEREO_RDS_DATA_SET_DS1                       1
#define RSSMB_STEREO_RDS_DATA_SET_DS2                       2
#define RSSMB_STEREO_RDS_DATA_SET_DS3                       3
#define RSSMB_STEREO_RDS_DATA_SET_DS4                       4
#define RSSMB_STEREO_RDS_DATA_SET_DS5                       5
    
/* --- Stereo Impedance ---------------------------------------------------- */
#define RSSMB_STEREO_EXT_INPUT_IMPEDANCE_100KO              0
#define RSSMB_STEREO_EXT_INPUT_IMPEDANCE_600O               1
    
/* --- Stereo Source ------------------------------------------------------- */
#define RSSMB_STEREO_SOURCE_OFF                             0
#define RSSMB_STEREO_SOURCE_LREX                            1
#define RSSMB_STEREO_SOURCE_SPEX                            2
#define RSSMB_STEREO_SOURCE_LFG                             3
    
/* --- Unit Power ---------------------------------------------------------- */     
#define RSSMB_UNIT_POWER_V                                  0
#define RSSMB_UNIT_POWER_DBM                                1
    
/* --- Sweep Shape --------------------------------------------------------- */
#define RSSMB_SWEEP_SHAPE_SAW                               0
#define RSSMB_SWEEP_SHAPE_TRI                               1
    
#define RSSMB_FREQ_SWEEP_SOURCE_LF1                         1
#define RSSMB_FREQ_SWEEP_SOURCE_LF2                         2
	
/* --- Power Sensor Measurement Mode --------------------------------------- */		
#define RSSMB_SENSE_POWER_MEAS_MODE_FREQ                    0
#define RSSMB_SENSE_POWER_MEAS_MODE_POW                     1
#define RSSMB_SENSE_POWER_MEAS_MODE_TIME                    2
	
/* --- Power Sensor Time Trigger Source ------------------------------------ */		
#define RSSMB_SENSE_POWER_TIME_TRIG_SOURCE_AUTO             0
#define RSSMB_SENSE_POWER_TIME_TRIG_SOURCE_FREE             1
#define RSSMB_SENSE_POWER_TIME_TRIG_SOURCE_EXT              2
	
/* --- Power Sensor Display Indication ------------------------------------- */		
#define RSSMB_SENSE_POWER_DISP_PULS_ALL                     0
#define RSSMB_SENSE_POWER_DISP_PULS                         1
#define RSSMB_SENSE_POWER_DISP_MARK                         2
#define RSSMB_SENSE_POWER_DISP_GATE                         3
#define RSSMB_SENSE_POWER_DISP_STAN                         4
#define RSSMB_SENSE_POWER_DISP_FULL_SCR                     5
	
/* --- Power Sensor Display Indication ------------------------------------- */		
#define RSSMB_SENSE_POWER_PERM_PRIOR_AVER                   0
#define RSSMB_SENSE_POWER_PERM_PRIOR_PEAK                   1
	
#define RSSMB_HCOPY_AUTO_FILE_DAY                           0
#define RSSMB_HCOPY_AUTO_FILE_MONTH                         1
#define RSSMB_HCOPY_AUTO_FILE_YEAR                          2
	
#define RSSMB_EXT_INPUT_IMPEDANCE_G50                       0
#define RSSMB_EXT_INPUT_IMPEDANCE_G1K                       1
	
#define RSSMB_CAL_DATA_FACT                                 0
#define RSSMB_CAL_DATA_CUST                                 1
	
#define RSSMB_HCOPY_SIZE_320_240                            0
#define RSSMB_HCOPY_SIZE_640_480                            1
#define RSSMB_HCOPY_SIZE_800_600                            2
#define RSSMB_HCOPY_SIZE_1024_768                           3
	
#define RSSMB_HCOPY_DEV_FILE                                0
	
/* --- DM Source ---------------------------------------------------------- */		
#define RSSMB_DM_SOURCE_EXT1 								0
#define RSSMB_DM_SOURCE_EXT2 								1
#define RSSMB_DM_SOURCE_PGEN 								2
#define RSSMB_DM_SOURCE_RAND 								3

/* --- Set ROSC External Frequency  --------------------------------------- */		
#define RSSMB_ROSC_EXTERNAL_FREQ_5MHZ  0
#define RSSMB_ROSC_EXTERNAL_FREQ_10MHZ 1
	
/* --- Set RF Mode  ------------------------------------------------------- */		
#define RSSMB_RF_MODE_NORMAL        						0
#define RSSMB_RF_MODE_LOWNOISE      						1
#define RSSMB_RF_MODE_LOWDISTORTION 						2
	
/* --- Set RF Attenuator Mode  -------------------------------------------- */		
#define RSSMB_RF_ATT_MODE_UNCHANGED 						0
#define RSSMB_RF_ATT_MODE_FATT      						1
	
/* --- Set ROSC External Synchronisation Bandwidth ------------------------ */		
#define RSSMB_EXTERN_SYNC_BW_NARROW 						0
#define RSSMB_EXTERN_SYNC_BW_WIDE   						1
	
/* --- Set Power Search Mode ---------------------------------------------- */			
#define RSSMB_POWER_SEARCH_MODE_NORMAL  					0
#define RSSMB_POWER_SEARCH_MODE_MINIMUM 					1
	
/* --- Set SYSTem Identification ------------------------------------------ */
#define RSSMB_IDENTIFICATION_AUTO 							0
#define RSSMB_IDENTIFICATION_USER 							1
	
/* --- Set Power Display Permanent Priority ------------------------------- */
#define RSSMB_PERMANENT_PRIORITY_AVERAGE 					0
#define RSSMB_PERMANENT_PRIORITY_PEAK    					1

	
/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/
ViStatus _VI_FUNC rssmb_init (ViRsrc resourceName, ViBoolean IDQuery,
                              ViBoolean resetDevice, ViPSession instrumentHandle);
ViStatus _VI_FUNC rssmb_ResetAllSweeps (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_confLFFreqSweep (ViSession instrumentHandle, ViInt32 mode,
                                         ViReal64 startFrequency,
                                         ViReal64 stopFrequency, ViInt32 spacing,
                                         ViReal64 step, ViReal64 dwellTime);
ViStatus _VI_FUNC rssmb_LFSweepTrigger (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_SetLFSweepMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rssmb_SetLFSweepStartFreq (ViSession instrumentHandle,
                                             ViReal64 startFrequency);
ViStatus _VI_FUNC rssmb_GetLFSweepStartFreq (ViSession instrumentHandle,
                                             ViPReal64 startFrequency);
ViStatus _VI_FUNC rssmb_SetLFSweepStopFreq (ViSession instrumentHandle,
                                            ViReal64 stopFrequency);
ViStatus _VI_FUNC rssmb_GetLFSweepStopFreq (ViSession instrumentHandle,
                                            ViPReal64 stopFrequency);
ViStatus _VI_FUNC rssmb_SetLFSweepSpacing (ViSession instrumentHandle,
                                           ViInt32 spacing);
ViStatus _VI_FUNC rssmb_GetLFSweepSpacing (ViSession instrumentHandle,
                                           ViPInt32 spacing);
ViStatus _VI_FUNC rssmb_SetLFSweepStepLin (ViSession instrumentHandle,
                                           ViReal64 stepLin);
ViStatus _VI_FUNC rssmb_GetLFSweepStepLin (ViSession instrumentHandle,
                                           ViPReal64 stepLin);
ViStatus _VI_FUNC rssmb_SetLFSweepStepLog (ViSession instrumentHandle,
                                           ViReal64 stepLog);
ViStatus _VI_FUNC rssmb_GetLFSweepStepLog (ViSession instrumentHandle,
                                           ViPReal64 stepLog);
ViStatus _VI_FUNC rssmb_SetLFSweepDwellTime (ViSession instrumentHandle,
                                             ViReal64 dwellTime);
ViStatus _VI_FUNC rssmb_GetLFSweepDwellTime (ViSession instrumentHandle,
                                             ViPReal64 dwellTime);
ViStatus _VI_FUNC rssmb_SetLFSweepManualStep (ViSession instrumentHandle,
                                              ViReal64 manualLFSweep);
ViStatus _VI_FUNC rssmb_GetLFSweepManualStep (ViSession instrumentHandle,
                                              ViPReal64 manualLFSweep);
ViStatus _VI_FUNC rssmb_SetLFSweepPoints (ViSession instrumentHandle,
                                          ViInt32 LFSweepPoints);
ViStatus _VI_FUNC rssmb_GetLFSweepPoints (ViSession instrumentHandle,
                                          ViPInt32 LFSweepPoints);
ViStatus _VI_FUNC rssmb_SetLFSweepShape (ViSession instrumentHandle, ViInt32 shape);
ViStatus _VI_FUNC rssmb_GetLFSweepShape (ViSession instrumentHandle,
                                         ViPInt32 shape);
ViStatus _VI_FUNC rssmb_SetLFSweepSource (ViSession instrumentHandle,
                                          ViInt32 source);
ViStatus _VI_FUNC rssmb_GetLFSweepSource (ViSession instrumentHandle,
                                          ViPInt32 source);
ViStatus _VI_FUNC rssmb_confLFFreq (ViSession instrumentHandle, ViBoolean state,
                                    ViReal64 LFGenFrequency, ViReal64 LFGenVoltage);
ViStatus _VI_FUNC rssmb_SetLFOutputState (ViSession instrumentHandle,
                                          ViBoolean LFOutputState);
ViStatus _VI_FUNC rssmb_GetLFOutputState (ViSession instrumentHandle,
                                          ViPBoolean LFOutputState);
ViStatus _VI_FUNC rssmb_SetLFGenVoltage (ViSession instrumentHandle,
                                         ViReal64 LFGenVoltage);
ViStatus _VI_FUNC rssmb_GetLFGenVoltage (ViSession instrumentHandle,
                                         ViPReal64 LFGenVoltage);
ViStatus _VI_FUNC rssmb_SetLFGenFrequency (ViSession instrumentHandle,
                                           ViReal64 LFGenFrequency);
ViStatus _VI_FUNC rssmb_GetLFGenFrequency (ViSession instrumentHandle,
                                           ViPReal64 LFGenFrequency);
ViStatus _VI_FUNC rssmb_SetLFGenShape (ViSession instrumentHandle, ViInt32 shape);
ViStatus _VI_FUNC rssmb_GetLFGenShape (ViSession instrumentHandle, ViPInt32 shape);
ViStatus _VI_FUNC rssmb_SetLFGenOutputImpedance (ViSession instrumentHandle,
                                                 ViInt32 outputImpedance);
ViStatus _VI_FUNC rssmb_GetLFGenOutputImpedance (ViSession instrumentHandle,
                                                 ViPInt32 outputImpedance);
ViStatus _VI_FUNC rssmb_SetPGENState (ViSession instrumentHandle,
                                      ViBoolean pulseGeneratorState);
ViStatus _VI_FUNC rssmb_GetPGENState (ViSession instrumentHandle,
                                      ViPBoolean pulseGeneratorState);
ViStatus _VI_FUNC rssmb_SetAllModulationsState (ViSession instrumentHandle,
                                                ViBoolean modulationsState);
ViStatus _VI_FUNC rssmb_SetAnalogModulationsExternalInputImpedance
             (ViSession instrumentHandle, ViInt32 externalInputImpedance);
ViStatus _VI_FUNC rssmb_GetAnalogModulationsExternalInputImpedance
             (ViSession instrumentHandle, ViPInt32 externalInputImpedance);
ViStatus _VI_FUNC rssmb_configAM (ViSession instrumentHandle, ViBoolean AMState,
                                  ViInt32 AMSource, ViReal64 AMDepth,
                                  ViInt32 AMExternalCoupling);
ViStatus _VI_FUNC rssmb_SetAMState (ViSession instrumentHandle, ViBoolean AMState);
ViStatus _VI_FUNC rssmb_GetAMState (ViSession instrumentHandle, ViPBoolean AMState);
ViStatus _VI_FUNC rssmb_SetAMSource (ViSession instrumentHandle, ViInt32 AMSource);
ViStatus _VI_FUNC rssmb_GetAMSource (ViSession instrumentHandle, ViPInt32 AMSource);
ViStatus _VI_FUNC rssmb_SetAMDepth (ViSession instrumentHandle, ViReal64 AMDepth);
ViStatus _VI_FUNC rssmb_GetAMDepth (ViSession instrumentHandle, ViPReal64 AMDepth);
ViStatus _VI_FUNC rssmb_SetAMExternalCoupling (ViSession instrumentHandle,
                                               ViInt32 AMExternalCoupling);
ViStatus _VI_FUNC rssmb_GetAMExternalCoupling (ViSession instrumentHandle,
                                               ViPInt32 AMExternalCoupling);
ViStatus _VI_FUNC rssmb_GetAMSensitivity (ViSession instrumentHandle,
                                          ViPReal64 AMSensitivity);
ViStatus _VI_FUNC rssmb_SetAMInternalDepth (ViSession instrumentHandle,
                                            ViReal64 AMInternalDepth);
ViStatus _VI_FUNC rssmb_GetAMInternalDepth (ViSession instrumentHandle,
                                            ViPReal64 AMInternalDepth);
ViStatus _VI_FUNC rssmb_confFM (ViSession instrumentHandle, ViBoolean state,
                                ViInt32 FMSource, ViInt32 mode,
                                ViReal64 FMDeviation, ViReal64 externalDeviation,
                                ViInt32 externalCoupling);
ViStatus _VI_FUNC rssmb_SetFMState (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rssmb_GetFMState (ViSession instrumentHandle, ViPBoolean state);
ViStatus _VI_FUNC rssmb_SetFMSource (ViSession instrumentHandle, ViInt32 source);
ViStatus _VI_FUNC rssmb_GetFMSource (ViSession instrumentHandle, ViPInt32 source);
ViStatus _VI_FUNC rssmb_SetFMMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rssmb_GetFMMode (ViSession instrumentHandle, ViPInt32 mode);
ViStatus _VI_FUNC rssmb_SetFMDeviation (ViSession instrumentHandle,
                                        ViReal64 externalDeviation);
ViStatus _VI_FUNC rssmb_GetFMDeviation (ViSession instrumentHandle,
                                        ViPReal64 externalDeviation);
ViStatus _VI_FUNC rssmb_SetFMExtCoupling (ViSession instrumentHandle,
                                          ViInt32 externalCoupling);
ViStatus _VI_FUNC rssmb_GetFMExtCoupling (ViSession instrumentHandle,
                                          ViPInt32 externalCoupling);
ViStatus _VI_FUNC rssmb_SetFMExternalDeviation (ViSession instrumentHandle,
                                                ViReal64 externalDeviation);
ViStatus _VI_FUNC rssmb_GetFMExternalDeviation (ViSession instrumentHandle,
                                                ViPReal64 externalDeviation);
ViStatus _VI_FUNC rssmb_GetFMSensitivity (ViSession instrumentHandle,
                                          ViPReal64 sensitivity);
ViStatus _VI_FUNC rssmb_confPM (ViSession instrumentHandle, ViBoolean state,
                                ViInt32 source, ViInt32 mode, ViReal64 PMDeviation,
                                ViReal64 externalDeviation,
                                ViInt32 externalCoupling);
ViStatus _VI_FUNC rssmb_SetPMState (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rssmb_GetPMState (ViSession instrumentHandle, ViPBoolean state);
ViStatus _VI_FUNC rssmb_SetPMSource (ViSession instrumentHandle, ViInt32 source);
ViStatus _VI_FUNC rssmb_GetPMSource (ViSession instrumentHandle, ViPInt32 source);
ViStatus _VI_FUNC rssmb_SetPMMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rssmb_GetPMMode (ViSession instrumentHandle, ViPInt32 mode);
ViStatus _VI_FUNC rssmb_SetPMDeviation (ViSession instrumentHandle,
                                        ViReal64 deviation);
ViStatus _VI_FUNC rssmb_GetPMDeviation (ViSession instrumentHandle,
                                        ViPReal64 deviation);
ViStatus _VI_FUNC rssmb_SetPMExtCoupling (ViSession instrumentHandle,
                                          ViInt32 externalCoupling);
ViStatus _VI_FUNC rssmb_GetPMExtCoupling (ViSession instrumentHandle,
                                          ViPInt32 externalCoupling);
ViStatus _VI_FUNC rssmb_SetPMExternalDeviation (ViSession instrumentHandle,
                                                ViReal64 externalDeviation);
ViStatus _VI_FUNC rssmb_GetPMExternalDeviation (ViSession instrumentHandle,
                                                ViPReal64 externalDeviation);
ViStatus _VI_FUNC rssmb_GetPMSensitivity (ViSession instrumentHandle,
                                          ViPReal64 sensitivity);
ViStatus _VI_FUNC rssmb_confPulm (ViSession instrumentHandle, ViBoolean state,
                                  ViInt32 source, ViInt32 polarity,
                                  ViBoolean pulseGeneratorState,
                                  ViReal64 pulsePeriod, ViReal64 pulseWidth,
                                  ViReal64 pulseDelay, ViBoolean doublePulseState,
                                  ViReal64 doublePulseWidth,
                                  ViReal64 doublePulseDelay);
ViStatus _VI_FUNC rssmb_SetPULMState (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rssmb_GetPULMState (ViSession instrumentHandle, ViPBoolean state);
ViStatus _VI_FUNC rssmb_SetPULMPolarity (ViSession instrumentHandle,
                                         ViInt32 polarity);
ViStatus _VI_FUNC rssmb_GetPULMPolarity (ViSession instrumentHandle,
                                         ViPInt32 polarity);
ViStatus _VI_FUNC rssmb_SetPULMSource (ViSession instrumentHandle, ViInt32 source);
ViStatus _VI_FUNC rssmb_GetPULMSource (ViSession instrumentHandle, ViPInt32 source);
ViStatus _VI_FUNC rssmb_SetPULMPeriod (ViSession instrumentHandle,
                                       ViReal64 pulsePeriod);
ViStatus _VI_FUNC rssmb_GetPULMPeriod (ViSession instrumentHandle,
                                       ViPReal64 pulsePeriod);
ViStatus _VI_FUNC rssmb_SetPULMWidth (ViSession instrumentHandle,
                                      ViReal64 pulseWidth);
ViStatus _VI_FUNC rssmb_GetPULMWidth (ViSession instrumentHandle,
                                      ViPReal64 pulseWidth);
ViStatus _VI_FUNC rssmb_SetPULMDelay (ViSession instrumentHandle,
                                      ViReal64 pulseDelay);
ViStatus _VI_FUNC rssmb_GetPULMDelay (ViSession instrumentHandle,
                                      ViPReal64 pulseDelay);
ViStatus _VI_FUNC rssmb_SetPULMDoubleState (ViSession instrumentHandle,
                                            ViBoolean doublePulseState);
ViStatus _VI_FUNC rssmb_GetPULMDoubleState (ViSession instrumentHandle,
                                            ViPBoolean doublePulseState);
ViStatus _VI_FUNC rssmb_SetPULMDoubleWidth (ViSession instrumentHandle,
                                            ViReal64 doublePulseWidth);
ViStatus _VI_FUNC rssmb_GetPULMDoubleWidth (ViSession instrumentHandle,
                                            ViPReal64 doublePulseWidth);
ViStatus _VI_FUNC rssmb_SetPULMDoubleDelay (ViSession instrumentHandle,
                                            ViReal64 doublePulseDelay);
ViStatus _VI_FUNC rssmb_GetPULMDoubleDelay (ViSession instrumentHandle,
                                            ViPReal64 doublePulseDelay);
ViStatus _VI_FUNC rssmb_SetPULMTrainRepetition (ViSession instrumentHandle,
                                                ViInt32 arraySize,
                                                ViInt32 _VI_FAR repetition[]);
ViStatus _VI_FUNC rssmb_GetPULMTrainRepetition (ViSession instrumentHandle,
                                                ViInt32 arraySize,
                                                ViInt32 _VI_FAR repetition[]);
ViStatus _VI_FUNC rssmb_GetPULMTrainRepetitionPoints (ViSession instrumentHandle,
                                                      ViPInt32 numberOfRepetitionPoints);
ViStatus _VI_FUNC rssmb_PULMTrainCatalog (ViSession instrumentHandle,
                                          ViInt32 arraySize,
                                          ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmb_PULMTrainSelect (ViSession instrumentHandle, ViString file);
ViStatus _VI_FUNC rssmb_PULMTrainDelete (ViSession instrumentHandle, ViString file);
ViStatus _VI_FUNC rssmb_SetPULMTrainOffTime (ViSession instrumentHandle,
                                             ViInt32 arraySize,
                                             ViReal64 offTime[]);
ViStatus _VI_FUNC rssmb_GetPULMTrainOffTime (ViSession instrumentHandle,
                                             ViInt32 arraySize,
                                             ViReal64 offTime[]);
ViStatus _VI_FUNC rssmb_GetPULMTrainOffTimePoints (ViSession instrumentHandle,
                                                   ViPInt32 offTimePoints);
ViStatus _VI_FUNC rssmb_SetPULMTrainOnTime (ViSession instrumentHandle,
                                            ViInt32 arraySize, ViReal64 onTime[]);
ViStatus _VI_FUNC rssmb_GetPULMTrainOnTime (ViSession instrumentHandle,
                                            ViInt32 arraySize, ViReal64 onTime[]);
ViStatus _VI_FUNC rssmb_GetPULMTrainOnTimePoints (ViSession instrumentHandle,
                                                  ViPInt32 onTimePoints);
ViStatus _VI_FUNC rssmb_SetPULMTrainImportExportListMode (ViSession instrumentHandle,
                                                          ViInt32 listMode);
ViStatus _VI_FUNC rssmb_GetPULMTrainImportExportListMode (ViSession instrumentHandle,
                                                          ViPInt32 listMode);
ViStatus _VI_FUNC rssmb_SetPULMTrainImportExportListFile (ViSession instrumentHandle,
                                                          ViString sourceFile);
ViStatus _VI_FUNC rssmb_GetPULMTrainImportExportListFile (ViSession instrumentHandle,
                                                          ViChar _VI_FAR sourceFile[]);
ViStatus _VI_FUNC rssmb_PULMTrainImportExportExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_SetPULMTrainImportExportASCIIFile
             (ViSession instrumentHandle, ViString ASCIISourceFile);
ViStatus _VI_FUNC rssmb_GetPULMTrainImportExportASCIIFile
             (ViSession instrumentHandle, ViChar _VI_FAR ASCIISourceFile[]);
ViStatus _VI_FUNC rssmb_SetPULMTrainImportExportASCIIExtension
             (ViSession instrumentHandle, ViInt32 extension);
ViStatus _VI_FUNC rssmb_GetPULMTrainImportExportASCIIExtension
             (ViSession instrumentHandle, ViPInt32 extension);
ViStatus _VI_FUNC rssmb_SetPULMTrainImportExportASCIIColumnSeparator
             (ViSession instrumentHandle, ViInt32 separator);
ViStatus _VI_FUNC rssmb_GetPULMTrainImportExportASCIIColumnSeparator
             (ViSession instrumentHandle, ViPInt32 separator);
ViStatus _VI_FUNC rssmb_SetPULMTrainImportExportASCIIDecimalSeparator
             (ViSession instrumentHandle, ViInt32 decimalSeparator);
ViStatus _VI_FUNC rssmb_GetPULMTrainImportExportASCIIDecimalSeparator
             (ViSession instrumentHandle, ViPInt32 decimalSeparator);
ViStatus _VI_FUNC rssmb_PULMTrainImportExportCatalog (ViSession instrumentHandle,
                                                      ViInt32 arraySize,
                                                      ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmb_confPulmTrigger (ViSession instrumentHandle,
                                         ViInt32 externalInputImpedance,
                                         ViInt32 triggerMode,
                                         ViInt32 extTriggerInputSlope,
                                         ViInt32 gateInputPolarity);
ViStatus _VI_FUNC rssmb_SetPULMExternalInputImpedance (ViSession instrumentHandle,
                                                       ViInt32 externalInputImpedance);
ViStatus _VI_FUNC rssmb_GetPULMExternalInputImpedance (ViSession instrumentHandle,
                                                       ViPInt32 externalInputImpedance);
ViStatus _VI_FUNC rssmb_SetPULMTriggerMode (ViSession instrumentHandle,
                                            ViInt32 triggerMode);
ViStatus _VI_FUNC rssmb_GetPULMTriggerMode (ViSession instrumentHandle,
                                            ViPInt32 triggerMode);
ViStatus _VI_FUNC rssmb_SetPULMExtTriggerInputSlope (ViSession instrumentHandle,
                                                     ViInt32 extTriggerInputSlope);
ViStatus _VI_FUNC rssmb_GetPULMExtTriggerInputSlope (ViSession instrumentHandle,
                                                     ViPInt32 extTriggerInputSlope);
ViStatus _VI_FUNC rssmb_SetPULMGateInputPolarity (ViSession instrumentHandle,
                                                  ViInt32 polarity);
ViStatus _VI_FUNC rssmb_GetPULMGateInputPolarity (ViSession instrumentHandle,
                                                  ViPInt32 polarity);
ViStatus _VI_FUNC rssmb_confStereoModulation (ViSession instrumentHandle,
                                              ViInt32 inputImpedance,
                                              ViReal64 maxModulationFrequency,
                                              ViReal64 FMDeviation, ViInt32 source,
                                              ViInt32 audioMode, ViInt32 ARIType,
                                              ViBoolean ARIState,
                                              ViBoolean pilotState,
                                              ViBoolean RDSState,
                                              ViBoolean stereoState);
ViStatus _VI_FUNC rssmb_StereoDirect (ViSession instrumentHandle, ViString command);
ViStatus _VI_FUNC rssmb_SetStereoExternalInputImpedance (ViSession instrumentHandle,
                                                         ViInt32 inputImpedance);
ViStatus _VI_FUNC rssmb_GetStereoExternalInputImpedance (ViSession instrumentHandle,
                                                         ViPInt32 inputImpedance);
ViStatus _VI_FUNC rssmb_SetStereoMaxModulationFrequency (ViSession instrumentHandle,
                                                         ViReal64 maxModulationFrequency);
ViStatus _VI_FUNC rssmb_GetStereoMaxModulationFrequency (ViSession instrumentHandle,
                                                         ViPReal64 maxModulationFrequency);
ViStatus _VI_FUNC rssmb_SetStereoFMDeviation (ViSession instrumentHandle,
                                              ViReal64 FMDeviation);
ViStatus _VI_FUNC rssmb_GetStereoFMDeviation (ViSession instrumentHandle,
                                              ViPReal64 FMDeviation);
ViStatus _VI_FUNC rssmb_SetStereoSource (ViSession instrumentHandle,
                                         ViInt32 source);
ViStatus _VI_FUNC rssmb_GetStereoSource (ViSession instrumentHandle,
                                         ViPInt32 source);
ViStatus _VI_FUNC rssmb_SetStereoState (ViSession instrumentHandle,
                                        ViBoolean stereoState);
ViStatus _VI_FUNC rssmb_GetStereoState (ViSession instrumentHandle,
                                        ViPBoolean stereoState);
ViStatus _VI_FUNC rssmb_GetStereoAdjustment (ViSession instrumentHandle,
                                             ViPInt32 adjustment);
ViStatus _VI_FUNC rssmb_confStereoARI (ViSession instrumentHandle, ViInt32 ARIType,
                                       ViReal64 ARIDeviation, ViInt32 ARIBKCode,
                                       ViBoolean ARIState);
ViStatus _VI_FUNC rssmb_SetStereoARIBKCode (ViSession instrumentHandle,
                                            ViInt32 ARIBKCode);
ViStatus _VI_FUNC rssmb_GetStereoARIBKCode (ViSession instrumentHandle,
                                            ViPInt32 ARIBKCode);
ViStatus _VI_FUNC rssmb_SetStereoARIDeviation (ViSession instrumentHandle,
                                               ViReal64 ARIDeviation);
ViStatus _VI_FUNC rssmb_GetStereoARIDeviation (ViSession instrumentHandle,
                                               ViPReal64 ARIDeviation);
ViStatus _VI_FUNC rssmb_SetStereoARIState (ViSession instrumentHandle,
                                           ViBoolean ARIState);
ViStatus _VI_FUNC rssmb_GetStereoARIState (ViSession instrumentHandle,
                                           ViPBoolean ARIState);
ViStatus _VI_FUNC rssmb_SetStereoARIType (ViSession instrumentHandle,
                                          ViInt32 ARIType);
ViStatus _VI_FUNC rssmb_GetStereoARIType (ViSession instrumentHandle,
                                          ViPInt32 ARIType);
ViStatus _VI_FUNC rssmb_SetStereoARITypeState (ViSession instrumentHandle,
                                               ViBoolean ARIState);
ViStatus _VI_FUNC rssmb_GetStereoARITypeState (ViSession instrumentHandle,
                                               ViPBoolean ARIState);
ViStatus _VI_FUNC rssmb_confStereoAudio (ViSession instrumentHandle,
                                         ViInt32 audioMode, ViReal64 audioFrequency,
                                         ViInt32 audioPreemphasis,
                                         ViBoolean audioPreemphasisState);
ViStatus _VI_FUNC rssmb_SetStereoAudioFrequency (ViSession instrumentHandle,
                                                 ViReal64 audioFrequency);
ViStatus _VI_FUNC rssmb_GetStereoAudioFrequency (ViSession instrumentHandle,
                                                 ViPReal64 audioFrequency);
ViStatus _VI_FUNC rssmb_SetStereoAudioMode (ViSession instrumentHandle,
                                            ViInt32 audioMode);
ViStatus _VI_FUNC rssmb_GetStereoAudioMode (ViSession instrumentHandle,
                                            ViPInt32 audioMode);
ViStatus _VI_FUNC rssmb_SetStereoAudioPreemphasis (ViSession instrumentHandle,
                                                   ViInt32 audioPreemphasis);
ViStatus _VI_FUNC rssmb_GetStereoAudioPreemphasis (ViSession instrumentHandle,
                                                   ViPInt32 audioPreemphasis);
ViStatus _VI_FUNC rssmb_SetStereoAudioPreemphasisState (ViSession instrumentHandle,
                                                        ViBoolean audioPreemphasisState);
ViStatus _VI_FUNC rssmb_GetStereoAudioPreemphasisState (ViSession instrumentHandle,
                                                        ViPBoolean audioPreemphasisState);
ViStatus _VI_FUNC rssmb_confStereoPilot (ViSession instrumentHandle,
                                         ViReal64 pilotPhase,
                                         ViReal64 pilotDeviation,
                                         ViBoolean pilotState);
ViStatus _VI_FUNC rssmb_SetStereoPilotState (ViSession instrumentHandle,
                                             ViBoolean pilotState);
ViStatus _VI_FUNC rssmb_GetStereoPilotState (ViSession instrumentHandle,
                                             ViPBoolean pilotState);
ViStatus _VI_FUNC rssmb_SetStereoPilotDeviation (ViSession instrumentHandle,
                                                 ViReal64 pilotDeviation);
ViStatus _VI_FUNC rssmb_GetStereoPilotDeviation (ViSession instrumentHandle,
                                                 ViPReal64 pilotDeviation);
ViStatus _VI_FUNC rssmb_SetStereoPilotPhase (ViSession instrumentHandle,
                                             ViReal64 pilotPhase);
ViStatus _VI_FUNC rssmb_GetStereoPilotPhase (ViSession instrumentHandle,
                                             ViPReal64 pilotPhase);
ViStatus _VI_FUNC rssmb_confStereoRDS (ViSession instrumentHandle,
                                       ViInt32 RDSDataSet, ViReal64 RDSDeviation,
                                       ViBoolean trafficProgramState,
                                       ViBoolean trafficAnnouncementState,
                                       ViBoolean RDSState);
ViStatus _VI_FUNC rssmb_StereoRDSPrgIdentification (ViSession instrumentHandle,
                                                    ViChar _VI_FAR programIdentification[]);
ViStatus _VI_FUNC rssmb_StereoRDSPrgName (ViSession instrumentHandle,
                                          ViChar _VI_FAR programName[]);
ViStatus _VI_FUNC rssmb_SetStereoRDSDataSet (ViSession instrumentHandle,
                                             ViInt32 RDSDataSet);
ViStatus _VI_FUNC rssmb_GetStereoRDSDataSet (ViSession instrumentHandle,
                                             ViPInt32 RDSDataSet);
ViStatus _VI_FUNC rssmb_SetStereoRDSDeviation (ViSession instrumentHandle,
                                               ViReal64 RDSDeviation);
ViStatus _VI_FUNC rssmb_GetStereoRDSDeviation (ViSession instrumentHandle,
                                               ViPReal64 RDSDeviation);
ViStatus _VI_FUNC rssmb_SetStereoRDSState (ViSession instrumentHandle,
                                           ViBoolean RDSState);
ViStatus _VI_FUNC rssmb_GetStereoRDSState (ViSession instrumentHandle,
                                           ViPBoolean RDSState);
ViStatus _VI_FUNC rssmb_SetStereoRDSTrafficAnnouncementState
             (ViSession instrumentHandle, ViBoolean trafficAnnouncementState);
ViStatus _VI_FUNC rssmb_GetStereoRDSTrafficAnnouncementState
             (ViSession instrumentHandle, ViPBoolean trafficAnnouncementState);
ViStatus _VI_FUNC rssmb_SetStereoRDSTrafficProgramState (ViSession instrumentHandle,
                                                         ViBoolean trafficProgramState);
ViStatus _VI_FUNC rssmb_GetStereoRDSTrafficProgramState (ViSession instrumentHandle,
                                                         ViPBoolean trafficProgramState);
ViStatus _VI_FUNC rssmb_SetAllRFOutputsState (ViSession instrumentHandle,
                                              ViBoolean RFOutputStates);
ViStatus _VI_FUNC rssmb_SetOutputState (ViSession instrumentHandle,
                                        ViBoolean RFOutputState);
ViStatus _VI_FUNC rssmb_GetOutputState (ViSession instrumentHandle,
                                        ViPBoolean RFOutputState);
ViStatus _VI_FUNC rssmb_GetOutputImpedance (ViSession instrumentHandle,
                                            ViPInt32 impedance);
ViStatus _VI_FUNC rssmb_SetRFMode (ViSession instrumentHandle, ViInt32 RFMode);
ViStatus _VI_FUNC rssmb_GetRFMode (ViSession instrumentHandle, ViPInt32 RFMode);
ViStatus _VI_FUNC rssmb_SetRFAttMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rssmb_GetRFAttMode (ViSession instrumentHandle, ViPInt32 mode);
ViStatus _VI_FUNC rssmb_SetRFLevel (ViSession instrumentHandle, ViReal64 RFLevel);
ViStatus _VI_FUNC rssmb_GetRFLevel (ViSession instrumentHandle, ViPReal64 RFLevel);
ViStatus _VI_FUNC rssmb_confRFFreq (ViSession instrumentHandle, ViReal64 frequency,
                                    ViReal64 offset, ViBoolean variationActive,
                                    ViReal64 variationStep);
ViStatus _VI_FUNC rssmb_SetRFFrequency (ViSession instrumentHandle,
                                        ViReal64 frequency);
ViStatus _VI_FUNC rssmb_GetRFFrequency (ViSession instrumentHandle,
                                        ViPReal64 frequency);
ViStatus _VI_FUNC rssmb_SetRFFrequencyOffset (ViSession instrumentHandle,
                                              ViReal64 frequencyOffset);
ViStatus _VI_FUNC rssmb_GetRFFrequencyOffset (ViSession instrumentHandle,
                                              ViPReal64 frequencyOffset);
ViStatus _VI_FUNC rssmb_SetRFVariationActive (ViSession instrumentHandle,
                                              ViBoolean variationActive);
ViStatus _VI_FUNC rssmb_GetRFVariationActive (ViSession instrumentHandle,
                                              ViPBoolean variationActive);
ViStatus _VI_FUNC rssmb_SetRFVariationStep (ViSession instrumentHandle,
                                            ViReal64 variationStep);
ViStatus _VI_FUNC rssmb_GetRFVariationStep (ViSession instrumentHandle,
                                            ViPReal64 variationStep);
ViStatus _VI_FUNC rssmb_SetRFFrequencyonRecall (ViSession instrumentHandle,
                                                ViInt32 RFFrequencyOnRecall);
ViStatus _VI_FUNC rssmb_GetRFFrequencyonRecall (ViSession instrumentHandle,
                                                ViPInt32 RFFrequencyOnRecall);
ViStatus _VI_FUNC rssmb_confRosc (ViSession instrumentHandle, ViInt32 ROSCSource,
                                  ViInt32 externalReferenceFrequency,
                                  ViBoolean adjustmentActive,
                                  ViInt32 adjustmentFrequency);
ViStatus _VI_FUNC rssmb_SetROSCSource (ViSession instrumentHandle,
                                       ViInt32 ROSCSource);
ViStatus _VI_FUNC rssmb_GetROSCSource (ViSession instrumentHandle,
                                       ViPInt32 ROSCSource);
ViStatus _VI_FUNC rssmb_SetROSCRFOutput (ViSession instrumentHandle,
                                         ViBoolean RFOutput);
ViStatus _VI_FUNC rssmb_GetROSCRFOutput (ViSession instrumentHandle,
                                         ViPBoolean RFOutput);
ViStatus _VI_FUNC rssmb_SetROSCExternalReferenceFrequency
             (ViSession instrumentHandle, ViInt32 externalReferenceFrequency);
ViStatus _VI_FUNC rssmb_GetROSCExternalReferenceFrequency
             (ViSession instrumentHandle, ViPInt32 externalReferenceFrequency);
ViStatus _VI_FUNC rssmb_SetROSCExternalSynchronisationBandwidth
             (ViSession instrumentHandle, ViInt32 synchronisationBandwidth);
ViStatus _VI_FUNC rssmb_GetROSCExternalSynchronisationBandwidth
             (ViSession instrumentHandle, ViPInt32 synchonisationBandwidth);
ViStatus _VI_FUNC rssmb_SetROSCAdjustmentActive (ViSession instrumentHandle,
                                                 ViBoolean adjustmentActive);
ViStatus _VI_FUNC rssmb_GetROSCAdjustmentActive (ViSession instrumentHandle,
                                                 ViPBoolean adjustmentActive);
ViStatus _VI_FUNC rssmb_SetROSCAdjustmentFrequency (ViSession instrumentHandle,
                                                    ViInt32 adjustmentFrequency);
ViStatus _VI_FUNC rssmb_GetROSCAdjustmentFrequency (ViSession instrumentHandle,
                                                    ViPInt32 adjustmentFrequency);
ViStatus _VI_FUNC rssmb_SetRFDeltaPhase (ViSession instrumentHandle,
                                         ViReal64 deltaPhase);
ViStatus _VI_FUNC rssmb_GetRFDeltaPhase (ViSession instrumentHandle,
                                         ViPReal64 deltaPhase);
ViStatus _VI_FUNC rssmb_ResetRFDeltaPhaseDisplay (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_confRFLevel (ViSession instrumentHandle, ViReal64 amplitude,
                                     ViReal64 offset, ViReal64 limit,
                                     ViBoolean variationActive,
                                     ViReal64 variationStep, ViInt32 attenuatorMode,
                                     ViInt32 RFLevelOnRecall);
ViStatus _VI_FUNC rssmb_SetRFAmplitude (ViSession instrumentHandle,
                                        ViReal64 amplitude);
ViStatus _VI_FUNC rssmb_GetRFAmplitude (ViSession instrumentHandle,
                                        ViPReal64 amplitude);
ViStatus _VI_FUNC rssmb_SetRFLevelLimit (ViSession instrumentHandle,
                                         ViReal64 limit);
ViStatus _VI_FUNC rssmb_GetRFLevelLimit (ViSession instrumentHandle,
                                         ViPReal64 limit);
ViStatus _VI_FUNC rssmb_SetRFLevelOffset (ViSession instrumentHandle,
                                          ViReal64 offset);
ViStatus _VI_FUNC rssmb_GetRFLevelOffset (ViSession instrumentHandle,
                                          ViPReal64 offset);
ViStatus _VI_FUNC rssmb_SetRFLevelonRecall (ViSession instrumentHandle,
                                            ViInt32 RFLevelOnRecall);
ViStatus _VI_FUNC rssmb_GetRFLevelonRecall (ViSession instrumentHandle,
                                            ViPInt32 RFLevelOnRecall);
ViStatus _VI_FUNC rssmb_SetRFAttenuatorMode (ViSession instrumentHandle,
                                             ViInt32 attenuatorMode);
ViStatus _VI_FUNC rssmb_GetRFAttenuatorMode (ViSession instrumentHandle,
                                             ViPInt32 attenuatorMode);
ViStatus _VI_FUNC rssmb_SetRFAttenuatorPowerSearchMode (ViSession instrumentHandle,
                                                        ViInt32 searchMode);
ViStatus _VI_FUNC rssmb_GetRFAttenuatorPowerSearchMode (ViSession instrumentHandle,
                                                        ViPInt32 searchMode);
ViStatus _VI_FUNC rssmb_GetRFAttenuatorLowerRange (ViSession instrumentHandle,
                                                   ViPReal64 attenuatorLowerRange);
ViStatus _VI_FUNC rssmb_GetRFAttenuatorUpperRange (ViSession instrumentHandle,
                                                   ViPReal64 attenuatorUpperRange);
ViStatus _VI_FUNC rssmb_SetRFLevelVariationActive (ViSession instrumentHandle,
                                                   ViBoolean variationActive);
ViStatus _VI_FUNC rssmb_GetRFLevelVariationActive (ViSession instrumentHandle,
                                                   ViPBoolean variationActive);
ViStatus _VI_FUNC rssmb_SetRFLevelVariationStep (ViSession instrumentHandle,
                                                 ViReal64 variationStep);
ViStatus _VI_FUNC rssmb_GetRFLevelVariationStep (ViSession instrumentHandle,
                                                 ViPReal64 variationStep);
ViStatus _VI_FUNC rssmb_SetRFPowerOnState (ViSession instrumentHandle,
                                           ViInt32 powerOnState);
ViStatus _VI_FUNC rssmb_GetRFPowerOnState (ViSession instrumentHandle,
                                           ViPInt32 powerOnState);
ViStatus _VI_FUNC rssmb_SetALCState (ViSession instrumentHandle, ViInt32 ALCState);
ViStatus _VI_FUNC rssmb_GetALCState (ViSession instrumentHandle, ViPInt32 ALCState);
ViStatus _VI_FUNC rssmb_ALCSearchOnce (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_SetUserCorrectionDataState (ViSession instrumentHandle,
                                                    ViBoolean correctionState);
ViStatus _VI_FUNC rssmb_GetUserCorrectionDataState (ViSession instrumentHandle,
                                                    ViPBoolean correctionState);
ViStatus _VI_FUNC rssmb_GetUserCorrectionDataCatalog (ViSession instrumentHandle,
                                                      ViString directoryPath,
                                                      ViInt32 arraySize,
                                                      ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmb_SetUserCorrectionDataTable (ViSession instrumentHandle,
                                                    ViString correctionTable);
ViStatus _VI_FUNC rssmb_GetUserCorrectionDataTable (ViSession instrumentHandle,
                                                    ViChar _VI_FAR correctionTable[]);
ViStatus _VI_FUNC rssmb_SetUserCorrectionDataFrequencyValues
             (ViSession instrumentHandle, ViInt32 arraySize,
              ViReal64 _VI_FAR frequencyValues[]);
ViStatus _VI_FUNC rssmb_GetUserCorrectionDataFrequencyValues
             (ViSession instrumentHandle, ViInt32 arraySize,
              ViReal64 _VI_FAR frequencyValues[]);
ViStatus _VI_FUNC rssmb_GetUserCorrectionDataNumberofFrequencyValues
             (ViSession instrumentHandle, ViPInt32 numberOfFrequencyValues);
ViStatus _VI_FUNC rssmb_SetUserCorrectionDataLevelValues (ViSession instrumentHandle,
                                                          ViInt32 arraySize,
                                                          ViReal64 _VI_FAR levelValues[]);
ViStatus _VI_FUNC rssmb_GetUserCorrectionDataLevelValues (ViSession instrumentHandle,
                                                          ViInt32 arraySize,
                                                          ViReal64 _VI_FAR levelValues[]);
ViStatus _VI_FUNC rssmb_GetUserCorrectionDataNumberofLevelValues
             (ViSession instrumentHandle, ViPInt32 numberOfLevelValues);
ViStatus _VI_FUNC rssmb_UserCorrectionDataDeleteTable (ViSession instrumentHandle,
                                                       ViString tableName);
ViStatus _VI_FUNC rssmb_UserCorrectionFillData (ViSession instrumentHandle,
                                                ViInt32 sensor);
ViStatus _VI_FUNC rssmb_GetUserCorrectionValue (ViSession instrumentHandle,
                                                ViPReal64 userCorrectionValue);
ViStatus _VI_FUNC rssmb_SetCORRectionImportExportListMode
             (ViSession instrumentHandle, ViInt32 listMode);
ViStatus _VI_FUNC rssmb_GetCORRectionImportExportListMode
             (ViSession instrumentHandle, ViPInt32 listMode);
ViStatus _VI_FUNC rssmb_SetCORRectionImportExportListFile
             (ViSession instrumentHandle, ViString sourceFile);
ViStatus _VI_FUNC rssmb_GetCORRectionImportExportListFile
             (ViSession instrumentHandle, ViChar _VI_FAR sourceFile[]);
ViStatus _VI_FUNC rssmb_CORRectionImportExportExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_SetCORRectionImportExportASCIIFile
             (ViSession instrumentHandle, ViString ASCIISourceFile);
ViStatus _VI_FUNC rssmb_GetCORRectionImportExportASCIIFile
             (ViSession instrumentHandle, ViChar _VI_FAR ASCIISourceFile[]);
ViStatus _VI_FUNC rssmb_SetCORRectionImportExportASCIIExtension
             (ViSession instrumentHandle, ViInt32 extension);
ViStatus _VI_FUNC rssmb_GetCORRectionImportExportASCIIExtension
             (ViSession instrumentHandle, ViPInt32 extension);
ViStatus _VI_FUNC rssmb_SetCORRectionImportExportASCIIColumnSeparator
             (ViSession instrumentHandle, ViInt32 separator);
ViStatus _VI_FUNC rssmb_GetCORRectionImportExportASCIIColumnSeparator
             (ViSession instrumentHandle, ViPInt32 separator);
ViStatus _VI_FUNC rssmb_SetCORRectionImportExportASCIIColumnDecimalSeparator
             (ViSession instrumentHandle, ViInt32 decimalSeparator);
ViStatus _VI_FUNC rssmb_GetCORRectionImportExportASCIIColumnDecimalSeparator
             (ViSession instrumentHandle, ViPInt32 decimalSeparator);
ViStatus _VI_FUNC rssmb_CORRectionImportExportCatalog (ViSession instrumentHandle,
                                                       ViString directoryPath,
                                                       ViInt32 arraySize,
                                                       ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmb_confFrequencySweep (ViSession instrumentHandle,
                                            ViInt32 mode, ViInt32 frequencySetting,
                                            ViReal64 centerFrequency, ViReal64 span,
                                            ViReal64 startFrequency,
                                            ViReal64 stopFrequency, ViInt32 spacing,
                                            ViReal64 step, ViReal64 dwellTime);
ViStatus _VI_FUNC rssmb_FrequencySweepExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_SetFrequencySweepMode (ViSession instrumentHandle,
                                               ViInt32 mode);
ViStatus _VI_FUNC rssmb_SetFrequencySweepStartFreq (ViSession instrumentHandle,
                                                    ViReal64 startFrequency);
ViStatus _VI_FUNC rssmb_GetFrequencySweepStartFreq (ViSession instrumentHandle,
                                                    ViPReal64 startFrequency);
ViStatus _VI_FUNC rssmb_SetFrequencySweepStopFreq (ViSession instrumentHandle,
                                                   ViReal64 stopFrequency);
ViStatus _VI_FUNC rssmb_GetFrequencySweepStopFreq (ViSession instrumentHandle,
                                                   ViPReal64 stopFrequency);
ViStatus _VI_FUNC rssmb_SetFrequencySweepCenterFreq (ViSession instrumentHandle,
                                                     ViReal64 centerFrequency);
ViStatus _VI_FUNC rssmb_GetFrequencySweepCenterFreq (ViSession instrumentHandle,
                                                     ViPReal64 centerFrequency);
ViStatus _VI_FUNC rssmb_SetFrequencySweepSpan (ViSession instrumentHandle,
                                               ViReal64 span);
ViStatus _VI_FUNC rssmb_GetFrequencySweepSpan (ViSession instrumentHandle,
                                               ViPReal64 span);
ViStatus _VI_FUNC rssmb_SetFrequencySweepShape (ViSession instrumentHandle,
                                                ViInt32 shape);
ViStatus _VI_FUNC rssmb_GetFrequencySweepShape (ViSession instrumentHandle,
                                                ViPInt32 shape);
ViStatus _VI_FUNC rssmb_SetFrequencySweepSpacing (ViSession instrumentHandle,
                                                  ViInt32 spacing);
ViStatus _VI_FUNC rssmb_GetFrequencySweepSpacing (ViSession instrumentHandle,
                                                  ViPInt32 spacing);
ViStatus _VI_FUNC rssmb_SetFrequencySweepStepLin (ViSession instrumentHandle,
                                                  ViReal64 stepLin);
ViStatus _VI_FUNC rssmb_GetFrequencySweepStepLin (ViSession instrumentHandle,
                                                  ViPReal64 stepLin);
ViStatus _VI_FUNC rssmb_SetFrequencySweepStepLog (ViSession instrumentHandle,
                                                  ViReal64 stepLog);
ViStatus _VI_FUNC rssmb_GetFrequencySweepStepLog (ViSession instrumentHandle,
                                                  ViPReal64 stepLog);
ViStatus _VI_FUNC rssmb_SetFrequencySweepDwellTime (ViSession instrumentHandle,
                                                    ViReal64 dwellTime);
ViStatus _VI_FUNC rssmb_GetFrequencySweepDwellTime (ViSession instrumentHandle,
                                                    ViPReal64 dwellTime);
ViStatus _VI_FUNC rssmb_SetFrequencySweepManualStep (ViSession instrumentHandle,
                                                     ViReal64 manualStep);
ViStatus _VI_FUNC rssmb_GetFrequencySweepManualStep (ViSession instrumentHandle,
                                                     ViPReal64 manualStep);
ViStatus _VI_FUNC rssmb_SetFrequencySweepPoints (ViSession instrumentHandle,
                                                 ViInt32 frequencySweepPoints);
ViStatus _VI_FUNC rssmb_GetFrequencySweepPoints (ViSession instrumentHandle,
                                                 ViPInt32 frequencySweepPoints);
ViStatus _VI_FUNC rssmb_SetFrequencySweepVoltageOut (ViSession instrumentHandle,
                                                     ViBoolean voltageOut);
ViStatus _VI_FUNC rssmb_GetFrequencySweepVoltageOut (ViSession instrumentHandle,
                                                     ViPBoolean voltageOut);
ViStatus _VI_FUNC rssmb_SetFrequencySweepStartVoltage (ViSession instrumentHandle,
                                                       ViReal64 startVoltage);
ViStatus _VI_FUNC rssmb_GetFrequencySweepStartVoltage (ViSession instrumentHandle,
                                                       ViPReal64 startVoltage);
ViStatus _VI_FUNC rssmb_SetFrequencySweepStopVoltage (ViSession instrumentHandle,
                                                      ViReal64 stopVoltage);
ViStatus _VI_FUNC rssmb_GetFrequencySweepStopVoltage (ViSession instrumentHandle,
                                                      ViPReal64 stopVoltage);
ViStatus _VI_FUNC rssmb_SetFrequencySweepMultiplier (ViSession instrumentHandle,
                                                     ViInt32 multiplier);
ViStatus _VI_FUNC rssmb_GetFrequencySweepMultiplier (ViSession instrumentHandle,
                                                     ViPInt32 multiplier);
ViStatus _VI_FUNC rssmb_confRFLevelSweep (ViSession instrumentHandle,
                                          ViInt32 levelSweepMode,
                                          ViReal64 startLevel, ViReal64 stopLevel,
                                          ViReal64 stepLin, ViReal64 dwellTime);
ViStatus _VI_FUNC rssmb_LevelSweepExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_SetLevelSweepMode (ViSession instrumentHandle,
                                           ViInt32 mode);
ViStatus _VI_FUNC rssmb_SetLevelSweepStartLevel (ViSession instrumentHandle,
                                                 ViReal64 startLevel);
ViStatus _VI_FUNC rssmb_GetLevelSweepStartLevel (ViSession instrumentHandle,
                                                 ViPReal64 startLevel);
ViStatus _VI_FUNC rssmb_SetLevelSweepStopLevel (ViSession instrumentHandle,
                                                ViReal64 stopLevel);
ViStatus _VI_FUNC rssmb_GetLevelSweepStopLevel (ViSession instrumentHandle,
                                                ViPReal64 stopLevel);
ViStatus _VI_FUNC rssmb_SetLevelSweepStep (ViSession instrumentHandle,
                                           ViReal64 step);
ViStatus _VI_FUNC rssmb_GetLevelSweepStep (ViSession instrumentHandle,
                                           ViPReal64 step);
ViStatus _VI_FUNC rssmb_SetLevelSweepDwell (ViSession instrumentHandle,
                                            ViReal64 dwellTime);
ViStatus _VI_FUNC rssmb_GetLevelSweepDwell (ViSession instrumentHandle,
                                            ViPReal64 dwellTime);
ViStatus _VI_FUNC rssmb_SetLevelSweepManualStep (ViSession instrumentHandle,
                                                 ViReal64 manualStep);
ViStatus _VI_FUNC rssmb_GetLevelSweepManualStep (ViSession instrumentHandle,
                                                 ViPReal64 manualStep);
ViStatus _VI_FUNC rssmb_SetLevelSweepPoints (ViSession instrumentHandle,
                                             ViInt32 levelSweepPoints);
ViStatus _VI_FUNC rssmb_GetLevelSweepPoints (ViSession instrumentHandle,
                                             ViPInt32 levelSweepPoints);
ViStatus _VI_FUNC rssmb_SetLevelSweepShape (ViSession instrumentHandle,
                                            ViInt32 shape);
ViStatus _VI_FUNC rssmb_GetLevelSweepShape (ViSession instrumentHandle,
                                            ViPInt32 shape);
ViStatus _VI_FUNC rssmb_GetLevelSweepSpacing (ViSession instrumentHandle,
                                              ViPInt32 spacing);
ViStatus _VI_FUNC rssmb_ResetLevelSweep (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_confList (ViSession instrumentHandle, ViString listName,
                                  ViInt32 listMode, ViInt32 arraySize,
                                  ViReal64 _VI_FAR frequencyValues[],
                                  ViReal64 _VI_FAR powerValues[],
                                  ViReal64 dwellTime);
ViStatus _VI_FUNC rssmb_LISTCatalog (ViSession instrumentHandle,
                                     ViString directoryPath, ViInt32 arraySize,
                                     ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmb_LISTDeleteList (ViSession instrumentHandle,
                                        ViString listName);
ViStatus _VI_FUNC rssmb_LISTDeleteAll (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_LISTResetList (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_LISTTriggerExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_SetLISTMode (ViSession instrumentHandle, ViInt32 listMode);
ViStatus _VI_FUNC rssmb_SetLISTDwellTime (ViSession instrumentHandle,
                                          ViReal64 dwellTime);
ViStatus _VI_FUNC rssmb_GetLISTDwellTime (ViSession instrumentHandle,
                                          ViPReal64 dwellTime);
ViStatus _VI_FUNC rssmb_SetLISTSelectList (ViSession instrumentHandle,
                                           ViString listName);
ViStatus _VI_FUNC rssmb_GetLISTSelectList (ViSession instrumentHandle,
                                           ViChar _VI_FAR listName[]);
ViStatus _VI_FUNC rssmb_SetLISTFrequencyValues (ViSession instrumentHandle,
                                                ViInt32 arraySize,
                                                ViReal64 _VI_FAR frequencyValues[]);
ViStatus _VI_FUNC rssmb_GetLISTFrequencyValues (ViSession instrumentHandle,
                                                ViInt32 arraySize,
                                                ViReal64 _VI_FAR frequencyValues[]);
ViStatus _VI_FUNC rssmb_GetLISTFrequencyPoints (ViSession instrumentHandle,
                                                ViPInt32 numberOfFrequencyPoints);
ViStatus _VI_FUNC rssmb_SetLISTPowerValues (ViSession instrumentHandle,
                                            ViInt32 arraySize,
                                            ViReal64 _VI_FAR powerValues[]);
ViStatus _VI_FUNC rssmb_GetLISTPowerValues (ViSession instrumentHandle,
                                            ViInt32 arraySize,
                                            ViReal64 _VI_FAR powerValues[]);
ViStatus _VI_FUNC rssmb_GetLISTPowerPoints (ViSession instrumentHandle,
                                            ViPInt32 numberOfPowerPoints);
ViStatus _VI_FUNC rssmb_SetLISTIndex (ViSession instrumentHandle, ViInt32 index);
ViStatus _VI_FUNC rssmb_GetLISTIndex (ViSession instrumentHandle, ViPInt32 index);
ViStatus _VI_FUNC rssmb_SetLISTStartIndex (ViSession instrumentHandle,
                                           ViInt32 startIndex);
ViStatus _VI_FUNC rssmb_GetLISTStartIndex (ViSession instrumentHandle,
                                           ViPInt32 startIndex);
ViStatus _VI_FUNC rssmb_SetLISTStopIndex (ViSession instrumentHandle,
                                          ViInt32 stopIndex);
ViStatus _VI_FUNC rssmb_GetLISTStopIndex (ViSession instrumentHandle,
                                          ViPInt32 stopIndex);
ViStatus _VI_FUNC rssmb_LearnLISTModeData (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_GetLISTFreeSpace (ViSession instrumentHandle,
                                          ViPInt32 freeSpace);
ViStatus _VI_FUNC rssmb_SetLISTImportExportListMode (ViSession instrumentHandle,
                                                     ViInt32 listMode);
ViStatus _VI_FUNC rssmb_GetLISTImportExportListMode (ViSession instrumentHandle,
                                                     ViPInt32 listMode);
ViStatus _VI_FUNC rssmb_SetLISTImportExportListFile (ViSession instrumentHandle,
                                                     ViString sourceFile);
ViStatus _VI_FUNC rssmb_GetLISTImportExportListFile (ViSession instrumentHandle,
                                                     ViChar _VI_FAR sourceFile[]);
ViStatus _VI_FUNC rssmb_ImportExportExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_SetLISTImportExportASCIIFile (ViSession instrumentHandle,
                                                      ViString ASCIISourceFile);
ViStatus _VI_FUNC rssmb_GetLISTImportExportASCIIFile (ViSession instrumentHandle,
                                                      ViChar _VI_FAR ASCIISourceFile[]);
ViStatus _VI_FUNC rssmb_SetLISTImportExportASCIIExtension
             (ViSession instrumentHandle, ViInt32 extension);
ViStatus _VI_FUNC rssmb_GetLISTImportExportASCIIExtension
             (ViSession instrumentHandle, ViPInt32 extension);
ViStatus _VI_FUNC rssmb_SetLISTImportExportASCIIColumnSeparator
             (ViSession instrumentHandle, ViInt32 separator);
ViStatus _VI_FUNC rssmb_GetLISTImportExportASCIIColumnSeparator
             (ViSession instrumentHandle, ViPInt32 separator);
ViStatus _VI_FUNC rssmb_SetLISTImportExportASCIIColumnDecimalSeparator
             (ViSession instrumentHandle, ViInt32 decimalSeparator);
ViStatus _VI_FUNC rssmb_GetLISTImportExportASCIIColumnDecimalSeparator
             (ViSession instrumentHandle, ViPInt32 decimalSeparator);
ViStatus _VI_FUNC rssmb_LISTImportExportCatalog (ViSession instrumentHandle,
                                                 ViUInt32 arraySize,
                                                 ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmb_confPowerSense (ViSession instrumentHandle, ViInt32 sense,
                                        ViBoolean continuous, ViInt32 unit,
                                        ViBoolean permanentDisplay, ViInt32 source,
                                        ViReal64 frequency, ViInt32 filterMode,
                                        ViBoolean useSParameters);
ViStatus _VI_FUNC rssmb_SetPowerUnit (ViSession instrumentHandle, ViInt32 sense,
                                      ViInt32 unit);
ViStatus _VI_FUNC rssmb_GetPowerUnit (ViSession instrumentHandle, ViInt32 sense,
                                      ViPInt32 unit);
ViStatus _VI_FUNC rssmb_SetPowerFrequency (ViSession instrumentHandle,
                                           ViInt32 sense, ViReal64 frequency);
ViStatus _VI_FUNC rssmb_GetPowerFrequency (ViSession instrumentHandle,
                                           ViInt32 sense, ViPReal64 frequency);
ViStatus _VI_FUNC rssmb_SetPowerOffset (ViSession instrumentHandle, ViInt32 sense,
                                        ViReal64 offset);
ViStatus _VI_FUNC rssmb_GetPowerOffset (ViSession instrumentHandle, ViInt32 sense,
                                        ViPReal64 offset);
ViStatus _VI_FUNC rssmb_SetPowerOffsetState (ViSession instrumentHandle,
                                             ViInt32 sense, ViBoolean offsetState);
ViStatus _VI_FUNC rssmb_GetPowerOffsetState (ViSession instrumentHandle,
                                             ViInt32 sense, ViPBoolean offsetState);
ViStatus _VI_FUNC rssmb_SetPowerSource (ViSession instrumentHandle, ViInt32 sense,
                                        ViInt32 source);
ViStatus _VI_FUNC rssmb_GetPowerSource (ViSession instrumentHandle, ViInt32 sense,
                                        ViPInt32 source);
ViStatus _VI_FUNC rssmb_PowerZero (ViSession instrumentHandle, ViInt32 sense);
ViStatus _VI_FUNC rssmb_SetPowerContinuous (ViSession instrumentHandle,
                                            ViInt32 sense, ViBoolean continuous);
ViStatus _VI_FUNC rssmb_GetPowerContinuous (ViSession instrumentHandle,
                                            ViInt32 sense, ViPBoolean continuous);
ViStatus _VI_FUNC rssmb_SetPowerUseSParameters (ViSession instrumentHandle,
                                                ViInt32 sense,
                                                ViBoolean useSParameters);
ViStatus _VI_FUNC rssmb_GetPowerUseSParameters (ViSession instrumentHandle,
                                                ViInt32 sense,
                                                ViPBoolean useSParameters);
ViStatus _VI_FUNC rssmb_SetPowerDisplayPermanentState (ViSession instrumentHandle,
                                                       ViInt32 sense,
                                                       ViBoolean permanentDisplay);
ViStatus _VI_FUNC rssmb_GetPowerDisplayPermanentState (ViSession instrumentHandle,
                                                       ViInt32 sense,
                                                       ViPBoolean permanentDisplay);
ViStatus _VI_FUNC rssmb_SetPowerDisplayPermanentPriority (ViSession instrumentHandle,
                                                          ViInt32 sense,
                                                          ViInt32 priority);
ViStatus _VI_FUNC rssmb_GetPowerDisplayPermanentPriority (ViSession instrumentHandle,
                                                          ViInt32 sense,
                                                          ViPInt32 priority);
ViStatus _VI_FUNC rssmb_PowerFilter (ViSession instrumentHandle, ViInt32 sense,
                                     ViInt32 filterMode, ViReal64 noiseContent,
                                     ViReal64 timeout);
ViStatus _VI_FUNC rssmb_SetPowerFilterLength (ViSession instrumentHandle,
                                              ViInt32 sense, ViInt32 filterLength);
ViStatus _VI_FUNC rssmb_GetPowerFilterLength (ViSession instrumentHandle,
                                              ViInt32 sense, ViPInt32 filterLength);
ViStatus _VI_FUNC rssmb_SetPowerSenseFilterMode (ViSession instrumentHandle,
                                                 ViInt32 sense, ViInt32 filterMode);
ViStatus _VI_FUNC rssmb_GetPowerSenseFilterMode (ViSession instrumentHandle,
                                                 ViInt32 sense,
                                                 ViPInt32 filterMode);
ViStatus _VI_FUNC rssmb_SetPowerFilterFixedNoiseContent (ViSession instrumentHandle,
                                                         ViInt32 sense,
                                                         ViReal64 noiseContent);
ViStatus _VI_FUNC rssmb_GetPowerFilterFixedNoiseContent (ViSession instrumentHandle,
                                                         ViInt32 sense,
                                                         ViPReal64 noiseContent);
ViStatus _VI_FUNC rssmb_SetPowerFilterFixedNoiseTimeout (ViSession instrumentHandle,
                                                         ViInt32 sense,
                                                         ViReal64 timeout);
ViStatus _VI_FUNC rssmb_GetPowerFilterFixedNoiseTimeout (ViSession instrumentHandle,
                                                         ViInt32 sense,
                                                         ViPReal64 timeout);
ViStatus _VI_FUNC rssmb_GetPowerFilterLengthAuto (ViSession instrumentHandle,
                                                  ViInt32 sense,
                                                  ViPInt32 filterLengthAuto);
ViStatus _VI_FUNC rssmb_PowerFilterSearchOnce (ViSession instrumentHandle,
                                               ViInt32 sense);
ViStatus _VI_FUNC rssmb_PowerSensorDevice (ViSession instrumentHandle,
                                           ViInt32 sense, ViPInt32 device);
ViStatus _VI_FUNC rssmb_PowerSensorType (ViSession instrumentHandle, ViInt32 sense,
                                         ViChar _VI_FAR type[]);
ViStatus _VI_FUNC rssmb_PowerReadPower (ViSession instrumentHandle, ViInt32 read,
                                        ViPReal64 power);
ViStatus _VI_FUNC rssmb_GetPowerSensorVersion (ViSession instrumentHandle,
                                               ViInt32 sense, ViInt32 arraySize,
                                               ViChar _VI_FAR version[]);
ViStatus _VI_FUNC rssmb_PowerSensorSerialNumber (ViSession instrumentHandle,
                                                 ViInt32 sense,
                                                 ViChar _VI_FAR serialNumber[]);
ViStatus _VI_FUNC rssmb_OvervoltageProtectionClear (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_OvervoltageProtectionTripped (ViSession instrumentHandle,
                                                      ViPInt32 protectiveCircuitState);
ViStatus _VI_FUNC rssmb_CALibrationAll (ViSession instrumentHandle, ViInt32 timeout,
                                        ViPInt32 response);
ViStatus _VI_FUNC rssmb_CALibrationClockSynthesis (ViSession instrumentHandle,
                                                   ViInt32 timeout,
                                                   ViPInt32 response);
ViStatus _VI_FUNC rssmb_CALibrationFMOffset (ViSession instrumentHandle,
                                             ViInt32 timeout, ViPInt32 response);
ViStatus _VI_FUNC rssmb_CALibrationFrequency (ViSession instrumentHandle,
                                              ViInt32 timeout, ViPInt32 response);
ViStatus _VI_FUNC rssmb_CALibrationModulationGenerators (ViSession instrumentHandle,
                                                         ViInt32 timeout,
                                                         ViPInt32 response);
ViStatus _VI_FUNC rssmb_CALibrationStereoCoder (ViSession instrumentHandle,
                                                ViInt32 timeout, ViPInt32 response);
ViStatus _VI_FUNC rssmb_CALibrationLevel (ViSession instrumentHandle,
                                          ViInt32 timeout, ViPInt32 response);
ViStatus _VI_FUNC rssmb_SetCALibrationLevelState (ViSession instrumentHandle,
                                                  ViBoolean levelState);
ViStatus _VI_FUNC rssmb_GetCALibrationLevelState (ViSession instrumentHandle,
                                                  ViPBoolean levelState);
ViStatus _VI_FUNC rssmb_SetCALibrationLevelAdjustmentData
             (ViSession instrumentHandle, ViInt32 adjustmentData);
ViStatus _VI_FUNC rssmb_GetCALibrationLevelAdjustmentData
             (ViSession instrumentHandle, ViPInt32 adjustmentData);
ViStatus _VI_FUNC rssmb_SetImageFileName (ViSession instrumentHandle,
                                          ViString fileName);
ViStatus _VI_FUNC rssmb_GetImageFileName (ViSession instrumentHandle,
                                          ViChar _VI_FAR fileName[]);
ViStatus _VI_FUNC rssmb_SetImageFormat (ViSession instrumentHandle,
                                        ViInt32 imageFormat);
ViStatus _VI_FUNC rssmb_GetImageFormat (ViSession instrumentHandle,
                                        ViPInt32 imageFormat);
ViStatus _VI_FUNC rssmb_GetImageSnapshot (ViSession instrumentHandle,
                                          ViString destination);
ViStatus _VI_FUNC rssmb_SetImageSize (ViSession instrumentHandle,
                                      ViInt32 imageSize);
ViStatus _VI_FUNC rssmb_GetImageSize (ViSession instrumentHandle,
                                      ViPInt32 imageSize);
ViStatus _VI_FUNC rssmb_SetOutputDevice (ViSession instrumentHandle,
                                         ViInt32 outputDevice);
ViStatus _VI_FUNC rssmb_GetOutputDevice (ViSession instrumentHandle,
                                         ViPInt32 outputDevice);
ViStatus _VI_FUNC rssmb_SaveHardCopy (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_SetAutomaticNamingState (ViSession instrumentHandle,
                                                 ViBoolean state);
ViStatus _VI_FUNC rssmb_GetAutomaticNamingState (ViSession instrumentHandle,
                                                 ViPBoolean state);
ViStatus _VI_FUNC rssmb_GetAutomaticFileName (ViSession instrumentHandle,
                                              ViChar _VI_FAR fileName[]);
ViStatus _VI_FUNC rssmb_GetAutomaticFilePath (ViSession instrumentHandle,
                                              ViInt32 arraySize,
                                              ViChar _VI_FAR filePath[]);
ViStatus _VI_FUNC rssmb_SetAutomaticDirectory (ViSession instrumentHandle,
                                               ViString directoryName);
ViStatus _VI_FUNC rssmb_GetAutomaticDirectory (ViSession instrumentHandle,
                                               ViChar _VI_FAR directory[]);
ViStatus _VI_FUNC rssmb_DeleteImageFiles (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_SetAutomaticFileDateState (ViSession instrumentHandle,
                                                   ViInt32 fileNamePart,
                                                   ViBoolean state);
ViStatus _VI_FUNC rssmb_GetAutomaticFileDateState (ViSession instrumentHandle,
                                                   ViInt32 fileNamePart,
                                                   ViPBoolean state);
ViStatus _VI_FUNC rssmb_GetAutomaticFileDate (ViSession instrumentHandle,
                                              ViInt32 fileNamePart,
                                              ViChar _VI_FAR part[]);
ViStatus _VI_FUNC rssmb_SetAutomaticFilePrefixState (ViSession instrumentHandle,
                                                     ViBoolean state);
ViStatus _VI_FUNC rssmb_GetAutomaticFilePrefixState (ViSession instrumentHandle,
                                                     ViPBoolean state);
ViStatus _VI_FUNC rssmb_SetAutomaticFilePrefix (ViSession instrumentHandle,
                                                ViString prefix);
ViStatus _VI_FUNC rssmb_GetAutomaticFilePrefix (ViSession instrumentHandle,
                                                ViChar _VI_FAR fileName[]);
ViStatus _VI_FUNC rssmb_GetAutomaticFileNumber (ViSession instrumentHandle,
                                                ViPInt32 number);
ViStatus _VI_FUNC rssmb_ClearStatus (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_EventStatusEnable (ViSession instrumentHandle,
                                           ViInt32 registerValue);
ViStatus _VI_FUNC rssmb_EventStatusQuery (ViSession instrumentHandle,
                                          ViPInt32 registerValue);
ViStatus _VI_FUNC rssmb_IdentificationQuery (ViSession instrumentHandle,
                                             ViChar _VI_FAR instrumentIdentification[]);
ViStatus _VI_FUNC rssmb_IndividualStatusQuery (ViSession instrumentHandle,
                                               ViPInt32 ISTFlag);
ViStatus _VI_FUNC rssmb_OperationComplete (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_OperationCompleteQuery (ViSession instrumentHandle,
                                                ViPInt32 OPCState);
ViStatus _VI_FUNC rssmb_OptionIdentificationQuery (ViSession instrumentHandle,
                                                   ViChar _VI_FAR optionIdentification[]);
ViStatus _VI_FUNC rssmb_ParallelPollRegisterEnable (ViSession instrumentHandle,
                                                    ViInt32 registerValue);
ViStatus _VI_FUNC rssmb_ParallelPollRegisterQuery (ViSession instrumentHandle,
                                                   ViPInt32 registerValue);
ViStatus _VI_FUNC rssmb_PowerOnStatusClear (ViSession instrumentHandle,
                                            ViInt32 registerValue);
ViStatus _VI_FUNC rssmb_PowerOnStatusClearQuery (ViSession instrumentHandle,
                                                 ViPInt32 registerValue);
ViStatus _VI_FUNC rssmb_Recall (ViSession instrumentHandle,
                                ViInt32 instrumentStatus);
ViStatus _VI_FUNC rssmb_Save (ViSession instrumentHandle, ViInt32 instrumentStatus);
ViStatus _VI_FUNC rssmb_ServiceRequestEnable (ViSession instrumentHandle,
                                              ViInt32 registerValue);
ViStatus _VI_FUNC rssmb_ServiceRequestEnableQuery (ViSession instrumentHandle,
                                                   ViPInt32 registerValue);
ViStatus _VI_FUNC rssmb_StatusByteQuery (ViSession instrumentHandle,
                                         ViPInt32 statusByte);
ViStatus _VI_FUNC rssmb_Trigger (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_TriggerWaitOPC (ViSession instrumentHandle,
                                        ViInt32 timeout);
ViStatus _VI_FUNC rssmb_SelfTestQuery (ViSession instrumentHandle,
                                       ViPInt32 errorCode);
ViStatus _VI_FUNC rssmb_WaittoContinue (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_PresetSignalPath (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_DIAGnosticModules (ViSession instrumentHandle,
                                           ViString moduleName, ViInt32 arraySize,
                                           ViChar _VI_FAR moduleConfiguration[]);
ViStatus _VI_FUNC rssmb_DIAGnosticModuleNames (ViSession instrumentHandle,
                                               ViInt32 arraySize,
                                               ViChar _VI_FAR moduleNames[]);
ViStatus _VI_FUNC rssmb_DIAGnosticTestPoints (ViSession instrumentHandle,
                                              ViInt32 arraySize,
                                              ViChar _VI_FAR testPoints[]);
ViStatus _VI_FUNC rssmb_DIAGnosticTestPointVoltages (ViSession instrumentHandle,
                                                     ViString testPointName,
                                                     ViPReal64 measuredVoltage);
ViStatus _VI_FUNC rssmb_DIAGnosticOperationTime (ViSession instrumentHandle,
                                                 ViPUInt32 operationTime);
ViStatus _VI_FUNC rssmb_DIAGnosticPowerOnEvents (ViSession instrumentHandle,
                                                 ViPUInt32 powerOnEvents);
ViStatus _VI_FUNC rssmb_TESTDirect (ViSession instrumentHandle, ViInt32 command,
                                    ViChar _VI_FAR assemblyResponse[]);
ViStatus _VI_FUNC rssmb_TESTAllStart (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_TESTAllResult (ViSession instrumentHandle,
                                       ViChar _VI_FAR result[]);
ViStatus _VI_FUNC rssmb_SetDisplayPowerSaveState (ViSession instrumentHandle,
                                                  ViBoolean state);
ViStatus _VI_FUNC rssmb_GetDisplayPowerSaveState (ViSession instrumentHandle,
                                                  ViPBoolean state);
ViStatus _VI_FUNC rssmb_SetDisplayPowerSaveHoldoff (ViSession instrumentHandle,
                                                    ViInt32 holdoff);
ViStatus _VI_FUNC rssmb_GetDisplayPowerSaveHoldoff (ViSession instrumentHandle,
                                                    ViPInt32 holdoff);
ViStatus _VI_FUNC rssmb_SetDisplayUpdateState (ViSession instrumentHandle,
                                               ViBoolean state);
ViStatus _VI_FUNC rssmb_GetDisplayUpdateState (ViSession instrumentHandle,
                                               ViPBoolean state);
ViStatus _VI_FUNC rssmb_MMEMoryCatalog (ViSession instrumentHandle,
                                        ViString directoryPath, ViInt32 arraySize,
                                        ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmb_MMEMoryCatalogLength (ViSession instrumentHandle,
                                              ViString directoryPath,
                                              ViPInt32 catalogLength);
ViStatus _VI_FUNC rssmb_MMEMoryChangeDirectory (ViSession instrumentHandle,
                                                ViString directoryName);
ViStatus _VI_FUNC rssmb_MMEMoryCopy (ViSession instrumentHandle,
                                     ViString sourcePath, ViString destinationPath);
ViStatus _VI_FUNC rssmb_MMEMoryBlockDataWrite (ViSession instrumentHandle,
                                               ViString fileName,
                                               ViInt32 binaryBlockLength,
                                               ViChar _VI_FAR binaryBlockData[]);
ViStatus _VI_FUNC rssmb_MMEMoryBlockDataRead (ViSession instrumentHandle,
                                              ViString fileName,
                                              ViInt32 binaryBlockLength,
                                              ViChar _VI_FAR binaryBlockData[]);
ViStatus _VI_FUNC rssmb_MMEMoryDirectoryCatalog (ViSession instrumentHandle,
                                                 ViString directoryPath,
                                                 ViInt32 arraySize,
                                                 ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssmb_MMEMoryDirectoryCatalogLength (ViSession instrumentHandle,
                                                       ViString directoryPath,
                                                       ViPInt32 catalogLength);
ViStatus _VI_FUNC rssmb_MMEMoryDelete (ViSession instrumentHandle,
                                       ViString fileName);
ViStatus _VI_FUNC rssmb_MMEMoryLoad (ViSession instrumentHandle,
                                     ViInt32 instrumentSetting, ViString fileName);
ViStatus _VI_FUNC rssmb_MMEMoryMakeDirectory (ViSession instrumentHandle,
                                              ViString directoryName);
ViStatus _VI_FUNC rssmb_MMEMoryMove (ViSession instrumentHandle,
                                     ViString fileSource, ViString fileDestination);
ViStatus _VI_FUNC rssmb_MMEMoryRemoveDirectory (ViSession instrumentHandle,
                                                ViString directoryName);
ViStatus _VI_FUNC rssmb_MMEMoryStore (ViSession instrumentHandle,
                                      ViInt32 instrumentSetting, ViString fileName);
ViStatus _VI_FUNC rssmb_setRegister (ViSession instrumentHandle,
                                     ViInt32 registerGroup, ViInt32 registerType,
                                     ViInt32 value);
ViStatus _VI_FUNC rssmb_getRegister (ViSession instrumentHandle,
                                     ViInt32 registerGroup, ViInt32 registerType,
                                     ViPInt32 value);
ViStatus _VI_FUNC rssmb_STATusPRESet (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_SetSYSTemBeeper (ViSession instrumentHandle,
                                         ViBoolean systemBeeper);
ViStatus _VI_FUNC rssmb_GetSYSTemBeeper (ViSession instrumentHandle,
                                         ViPBoolean systemBeeper);
ViStatus _VI_FUNC rssmb_SYSTemErrorQueueAll (ViSession instrumentHandle,
                                             ViInt32 arraySize,
                                             ViChar _VI_FAR errorQueue[]);
ViStatus _VI_FUNC rssmb_SYSTemErrorQueueCodeAll (ViSession instrumentHandle,
                                                 ViInt32 arraySize,
                                                 ViChar _VI_FAR errorQueueCode[]);
ViStatus _VI_FUNC rssmb_SYSTemErrorQueueCodeNext (ViSession instrumentHandle,
                                                  ViPInt32 errorQueueCodeNext);
ViStatus _VI_FUNC rssmb_SYSTemErrorQueueCount (ViSession instrumentHandle,
                                               ViPInt32 errorQueueCount);
ViStatus _VI_FUNC rssmb_SYSTemUSBResource (ViSession instrumentHandle,
                                           ViUInt32 arraySize,
                                           ViChar _VI_FAR USBResource[]);
ViStatus _VI_FUNC rssmb_SYSTemGPIBResource (ViSession instrumentHandle,
                                            ViInt32 arraySize,
                                            ViChar _VI_FAR GPIBResource[]);
ViStatus _VI_FUNC rssmb_SYSTemSerialResource (ViSession instrumentHandle,
                                              ViInt32 arraySize,
                                              ViChar _VI_FAR serialResource[]);
ViStatus _VI_FUNC rssmb_SYSTemOptionUserDefined (ViSession instrumentHandle,
                                                 ViString userDefinedIdentification);
ViStatus _VI_FUNC rssmb_SYSTemFactoryPreset (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_SetSYSTemKeyboardLock (ViSession instrumentHandle,
                                               ViBoolean keyboardLock);
ViStatus _VI_FUNC rssmb_GetSYSTemKeyboardLock (ViSession instrumentHandle,
                                               ViPBoolean keyboardLock);
ViStatus _VI_FUNC rssmb_SetSYSTemDisplayLock (ViSession instrumentHandle,
                                              ViBoolean displayLock);
ViStatus _VI_FUNC rssmb_GetSYSTemDisplayLock (ViSession instrumentHandle,
                                              ViPBoolean displayLock);
ViStatus _VI_FUNC rssmb_SetSYSTemProtect (ViSession instrumentHandle,
                                          ViInt32 protectionLevel,
                                          ViBoolean protection, ViString password);
ViStatus _VI_FUNC rssmb_GetSYSTemVersion (ViSession instrumentHandle,
                                          ViChar _VI_FAR SCPIVersion[]);
ViStatus _VI_FUNC rssmb_GetSYSTemStartupStatus (ViSession instrumentHandle,
                                                ViPInt32 startupComplete);
ViStatus _VI_FUNC rssmb_SetSYSTemNetworkIPAddress (ViSession instrumentHandle,
                                                   ViString IPAddress);
ViStatus _VI_FUNC rssmb_GetSYSTemNetworkIPAddress (ViSession instrumentHandle,
                                                   ViUInt32 arraySize,
                                                   ViChar _VI_FAR IPAddress[]);
ViStatus _VI_FUNC rssmb_SetSYSTemNetworkIPAddressSubnetMask
             (ViSession instrumentHandle, ViString IPAddressSubnetMask);
ViStatus _VI_FUNC rssmb_GetSYSTemNetworkIPAddressSubnetMask
             (ViSession instrumentHandle, ViUInt32 arraySize,
              ViChar _VI_FAR IPAddressSubnetMask[]);
ViStatus _VI_FUNC rssmb_SetSYSTemNetworkIPAddressGateway (ViSession instrumentHandle,
                                                          ViString IPAddressGateway);
ViStatus _VI_FUNC rssmb_GetSYSTemNetworkIPAddressGateway (ViSession instrumentHandle,
                                                          ViUInt32 arraySize,
                                                          ViChar _VI_FAR IPAddressGateway[]);
ViStatus _VI_FUNC rssmb_SetSYSTemNetworkIPAddressMode (ViSession instrumentHandle,
                                                       ViInt32 IPAddressMode);
ViStatus _VI_FUNC rssmb_GetSYSTemNetworkIPAddressMode (ViSession instrumentHandle,
                                                       ViPInt32 IPAddressMode);
ViStatus _VI_FUNC rssmb_SYSTemNetworkIPAddressExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_SetSYSTemNetworkCommonWorkgroup (ViSession instrumentHandle,
                                                         ViString commonWorkgroup);
ViStatus _VI_FUNC rssmb_GetSYSTemNetworkCommonWorkgroup (ViSession instrumentHandle,
                                                         ViUInt32 arraySize,
                                                         ViChar _VI_FAR commonWorkgroup[]);
ViStatus _VI_FUNC rssmb_SetSYSTemNetworkCommonDomain (ViSession instrumentHandle,
                                                      ViString commonDomain);
ViStatus _VI_FUNC rssmb_GetSYSTemNetworkCommonDomain (ViSession instrumentHandle,
                                                      ViUInt32 arraySize,
                                                      ViChar _VI_FAR commonDomain[]);
ViStatus _VI_FUNC rssmb_SetSYSTemNetworkCommonHostname (ViSession instrumentHandle,
                                                        ViString commonHostname);
ViStatus _VI_FUNC rssmb_GetSYSTemNetworkCommonHostname (ViSession instrumentHandle,
                                                        ViUInt32 arraySize,
                                                        ViChar _VI_FAR commonHostname[]);
ViStatus _VI_FUNC rssmb_SetSYSTemNetworkDomain (ViSession instrumentHandle,
                                                ViString domain);
ViStatus _VI_FUNC rssmb_GetSYSTemNetworkDomain (ViSession instrumentHandle,
                                                ViUInt32 arraySize,
                                                ViChar _VI_FAR domain[]);
ViStatus _VI_FUNC rssmb_SetSYSTemNetworkGateway (ViSession instrumentHandle,
                                                 ViString gateway);
ViStatus _VI_FUNC rssmb_GetSYSTemNetworkGateway (ViSession instrumentHandle,
                                                 ViUInt32 arraySize,
                                                 ViChar _VI_FAR gateway[]);
ViStatus _VI_FUNC rssmb_GetSYSTemNetworkResource (ViSession instrumentHandle,
                                                  ViUInt32 arraySize,
                                                  ViChar _VI_FAR resource[]);
ViStatus _VI_FUNC rssmb_SetSYSTemNetworkSubnetMask (ViSession instrumentHandle,
                                                    ViString subnetMask);
ViStatus _VI_FUNC rssmb_GetSYSTemNetworkSubnetMask (ViSession instrumentHandle,
                                                    ViUInt32 arraySize,
                                                    ViChar _VI_FAR subnetMask[]);
ViStatus _VI_FUNC rssmb_SetSYSTemNetworkWorkgroup (ViSession instrumentHandle,
                                                   ViString workgroup);
ViStatus _VI_FUNC rssmb_GetSYSTemNetworkWorkgroup (ViSession instrumentHandle,
                                                   ViUInt32 arraySize,
                                                   ViChar _VI_FAR workgroup[]);
ViStatus _VI_FUNC rssmb_GetSYSTemNetworkMACAddress (ViSession instrumentHandle,
                                                    ViUInt32 arraySize,
                                                    ViChar _VI_FAR MACAddress[]);
ViStatus _VI_FUNC rssmb_GetSYSTemNetwork (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_SetInstrumentTriggerInputSlope (ViSession instrumentHandle,
                                                        ViInt32 inputTriggerSlope);
ViStatus _VI_FUNC rssmb_GetInstrumentTriggerInputSlope (ViSession instrumentHandle,
                                                        ViPInt32 inputTriggerSlope);
ViStatus _VI_FUNC rssmb_TriggerSourceAllSweeps (ViSession instrumentHandle,
                                                ViInt32 triggerSourceAllSweeps);
ViStatus _VI_FUNC rssmb_TriggerAllSweeps (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_TriggerRFFrequencySweep (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_TriggerRFLevelSweep (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_TriggerListMode (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_SetAngleUnits (ViSession instrumentHandle,
                                       ViInt32 angleUnits);
ViStatus _VI_FUNC rssmb_GetAngleUnits (ViSession instrumentHandle,
                                       ViPInt32 angleUnits);
ViStatus _VI_FUNC rssmb_SetPowerUnits (ViSession instrumentHandle,
                                       ViInt32 powerUnits);
ViStatus _VI_FUNC rssmb_GetPowerUnits (ViSession instrumentHandle,
                                       ViPInt32 powerUnits);
ViStatus _VI_FUNC rssmb_SetVelocityUnits (ViSession instrumentHandle,
                                          ViInt32 velocityUnits);
ViStatus _VI_FUNC rssmb_GetVelocityUnits (ViSession instrumentHandle,
                                          ViPInt32 velocityUnits);
ViStatus _VI_FUNC rssmb_readToFile (ViSession instrumentHandle, ViString source,
                                    ViString destination);
ViStatus _VI_FUNC rssmb_writeFromFile (ViSession instrumentHandle, ViString source,
                                       ViString destination);
ViStatus _VI_FUNC rssmb_errorCheckState (ViSession instrumentHandle,
                                         ViBoolean stateChecking);
ViStatus _VI_FUNC rssmb_optionCheckState (ViSession instrumentHandle,
                                          ViBoolean stateChecking);
ViStatus _VI_FUNC rssmb_setCheckRange (ViSession instrumentHandle,
                                       ViBoolean rangeChecking);
ViStatus _VI_FUNC rssmb_writeInstrData (ViSession instrumentHandle,
                                        ViString writeBuffer);
ViStatus _VI_FUNC rssmb_readInstrData (ViSession instrumentHandle,
                                       ViInt32 numberBytesToRead,
                                       ViChar _VI_FAR readBuffer[],
                                       ViPInt32 numBytesRead);
ViStatus _VI_FUNC rssmb_DevicePreset (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmb_self_test (ViSession instrumentHandle,
                                   ViPInt16 selfTestResult,
                                   ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rssmb_error_query (ViSession instrumentHandle, ViPInt32 errorCode,
                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssmb_error_message (ViSession instrumentHandle,
                                       ViStatus statusCode,
                                       ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rssmb_revision_query (ViSession instrumentHandle,
                                        ViChar _VI_FAR instrumentDriverRevision[],
                                        ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rssmb_delay (ViSession instrumentHandle, ViReal64 seconds);
ViStatus _VI_FUNC rssmb_close (ViSession instrumentHandle);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
