#include <visa.h>

/*= Useful Macros ===========================================================*/

/* - Basic Macros ---------------------------------------------------------- */

/* Error checking macro */
#define CHECKERR(fCal) if (rssmb_status = (fCal), rssmb_status < VI_SUCCESS) \
    return rssmb_status

/* Error checking macro with jump to the ERROR: label */
#define GOCHECKERR(fCal) if (rssmb_status = (fCal), rssmb_status < VI_SUCCESS) \
                            goto ERROR_LABEL
/**#define GOCHECKERR(fCal) if (rssmb_status = (fCal), rssmb_status < VI_SUCCESS) \
                            goto ERROR_LABEL; else
*/
/* Parameter checking macro */
#define CHECKPARAM(fCal,param) if (fCal != VI_SUCCESS) return VI_ERROR_PARAMETER##param

/* Checking path parameter */
#define CHECKPATH if (rssmb_invalidViInt32Range (path, RSSMB_PATH_A, RSSMB_PATH_B)) return VI_ERROR_PARAMETER2;

/* Initialize default function parameters */
#define INIT\
    ViStatus            rssmb_status = VI_SUCCESS; \
    rssmb_instrRange    instrPtr = NULL; \
    CHECKERR (viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));\
    if (instrPtr == NULL)\
        return VI_ERROR_INSTR_PARAMETER

/* Close function and return */
#define RETURN\
    return rssmb_status;

/* - Additional Macros ----------------------------------------------------- */

#define CHECKOPT(option) if (instrPtr->optionChecking == VI_TRUE)\
                         {\
                            if (instrPtr->instrOptions.option == 0)\
                                return RSSMB_ERROR_INSTRUMENT_OPTION;\
                         }

#define CHECKOPTCONT(option) if (instrPtr->optionChecking == VI_TRUE)\
                         {\
                            if (instrPtr->instrOptions.option == 0)\
                                rssmb_status = RSSMB_ERROR_INSTRUMENT_OPTION;\
                         }
/* Check NULL pointer */
#define CHECKNULL(pointer) if (pointer == NULL) return rssmb_ParameterError(instrSession,#pointer)


/* Supported instruments */
#define SMB             0
#define SMC             1

/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT STATUS/RANGE STRUCTURE  ============================*/
/*****************************************************************************/
/* rssmb_stringValPair is used in the rssmb_error_message function           */
/* rssmb_statusDataRanges is used to track session dependent status & ranges */
/*===========================================================================*/
typedef struct  rssmb_stringValPair
{
   ViStatus stringVal;
   ViString stringName;
}  rssmb_tStringValPair;

typedef struct rssmb_instrOptions
{
    int B1:1;
    int B106:1;
    int K22:1;
    int K23:1;
	int K27:1;
	int K28:1;
} rssmb_tinstrOptions;

struct rssmb_statusDataRanges
{
    ViChar              instrDriverRevision[256];
    ViBoolean           errorChecking;
    ViBoolean           optionChecking;
    ViBoolean           rangeChecking;
    ViInt32             instrVer;
    rssmb_tinstrOptions instrOptions;
    ViChar      parameterErrorMessage[256];
};

typedef struct rssmb_statusDataRanges *rssmb_instrRange;
ViBoolean rssmb_invalidViBooleanRange (ViSession instrSession, ViBoolean val);
ViBoolean rssmb_invalidViInt32Range (ViSession instrSession, ViInt32 val, ViInt32 min, ViInt32 max);
ViBoolean rssmb_invalidViReal64Range (ViSession instrSession, ViReal64 val, ViReal64 min,
                                       ViReal64 max);
ViStatus rssmb_checkStatus (ViSession instrSession);
ViStatus rssmb_waitOPC (ViSession instrSession, ViPString command,
                        ViPString instrResp, ViInt32 timeout);
ViStatus rssmb_sendCmd (ViSession instrSession, ViString cmd);
ViStatus rssmb_setViInt32 (ViSession instrSession,
                           ViString cmd,
                           ViInt32 value,
                           ViInt32 min,
                           ViInt32 max,
                           ViString parameterName);
ViStatus rssmb_getViInt32 (ViSession instrSession,
                           ViString cmd,
                           ViInt32 *value,
                           ViString parameterName);
ViStatus rssmb_setViBoolean (ViSession instrSession,
                           ViString cmd,
                           ViBoolean value,
                           ViString parameterName);
ViStatus rssmb_getViBoolean (ViSession instrSession,
                           ViString cmd,
                           ViBoolean *value,
                           ViString parameterName);
ViStatus rssmb_setViReal64 (ViSession vi,
                            ViString cmd,
                            ViReal64 value,
                            ViReal64 min,
                            ViReal64 max,
                            ViString parameterName);
ViStatus rssmb_getViReal64 (ViSession instrSession,
                            ViString cmd,
                            ViReal64 *value,
                            ViString parameterName);
ViStatus rssmb_setViReal64Units (ViSession instrSession,
                                 ViString cmd,
                                 ViReal64 value,
                                 ViString units,
                                 ViReal64 min,
                                 ViReal64 max,
                                 ViString parameterName);
ViStatus rssmb_setViString (ViSession instrSession,
                            ViString cmd,
                            ViString value,
                            ViString parameterName);
ViStatus rssmb_getViString (ViSession instrSession,
                            ViString cmd,
                            ViString value,
                            ViUInt32 buffer_size,
                            ViString parameterName);
ViStatus rssmb_setViStringQuoted (ViSession instrSession,
                            ViString cmd,
                            ViString quotes,
                            ViString value,
                            ViString parameterName);
ViStatus rssmb_setEnum (ViSession instrSession,
                        ViString cmd,
                        ViInt32 value,
                        ViString list[],
                        ViString parameterName);
ViStatus rssmb_getEnum (ViSession instrSession,
                        ViString cmd,
                        ViInt32 *value,
                        ViString list[],
                        ViString parameterName);
ViStatus rssmb_checkIndexInList (ViSession instrSession,
								 ViInt32 index,
                                 ViString list[],
                                 ViString parameterName);
ViStatus rssmb_getIndexFromString (ViString string,
                                   ViString *list,
                                   ViInt32 *index);
ViStatus rssmb_getCatalog (ViSession instrSession,
                           ViString cmd,
                           ViUInt32 arraySize,
                           ViChar* array,
                           ViString parameterName);
ViStatus rssmb_getViReal64Array (ViSession instrSession,
                            ViString cmd,
                            ViReal64 *value,
                            ViInt32  count,
                            ViString parameterName);
ViStatus rssmb_getViInt32Array (ViSession instrSession,
                            ViString cmd,
                            ViInt32 *value,
                            ViInt32  count,
                            ViString parameterName);
ViStatus rssmb_readDataUnknownLength(ViSession instrSession,
                                     /*@null@*/ViChar **outBuffer,
                                     ViUInt32 *count);
ViStatus rssmb_getViUInt32 (ViSession instrSession,
                           ViString cmd,
                           ViUInt32 *value,
                           ViString parameterName);
void rssmb_SWAP_32(unsigned char *data, long points);
ViStatus _VI_FUNC rssmb_ReadTraceData(
    ViSession   instrSession,
    ViString    cmd,
    ViInt32*    noofPoints,
    ViReal64    _VI_FAR traceData[]
);
ViStatus rssmb_checkBeforeRead (ViSession instrSession);
ViStatus rssmb_readDataToFile (ViSession instrSession, ViString cmd,
                           ViString destination);
ViStatus rssmb_checkInstrument (ViSession instrSession, ViInt32 instrument, ViBoolean generateErrorIfPresent);
ViStatus rssmb_setViReal64Array (ViSession instrSession,
                            ViString cmd,
                            ViReal64 value[],
                            ViInt32  count,
                            ViString parameterName);
ViStatus rssmb_ParameterError (ViSession io, ViString parameterName);
